#include "itemsmanage.h"

ParaItem makeAParaItem(
        int64_t mcenSel,
        int paraType,
        int paraTypeSort,
        int indexInPara,
        int bitInWord,
        int readonly,
        int valueType,
        QString paraName,
        int64_t value,
        int64_t minval,
        int64_t maxval,
        int64_t defvalue,
        int afterpoint,
        QString unitstr,
        QString valuestr,
        QString selList,
        int selIdx,
        int defIdx,
        int showPriority,
        int authority)
{
    ParaItem item;

    item.clean();

    item.mcenSel        = mcenSel;      /* 机型选择 */
    item.paraType       = paraType;     /* 参数类型(机器参数、工作参数、花样设置参数...) */
    item.paraTypeSort   = paraTypeSort; /* 参数类型分类(机器参数的速度参数、机器参数的动作参数...) */

    item.indexInPara    = indexInPara;  /* 参数索引，-1，提示型显示; >= 0，该条目在参数中的位置*/
    item.bitInWord      = bitInWord;    /* 参数位索引 */
    item.readonly       = readonly;     /* 只读标志 */
    item.valueType      = valueType;    /* 参数值类型 = 0, 无值; = 1, 数字输入型; = 2, 开关选择型; = 3, 列表选择型 */

    item.paraName       = paraName;     /* 参数名称 */

    item.value          = value;        /* int输入型或选择型参数值 */
    item.minVal         = minval;       /* int输入型参数值范围下限 */
    item.maxVal         = maxval;       /* int输入型参数值范围上限 */
    item.defValue       = defvalue;     /* int输入型或选择型默认参数值 */
    item.afterPoint     = afterpoint;   /* int输入型保留小数位数 */
    item.unitStr        = unitstr;      /* int输入型单位字符串 */
    item.valueStr       = valuestr;     /* 字符输入型参数字符串 */

    item.selList        = selList;      /* 列表选择型的参数列表, 通过"\n"来分割 */
    item.selIdx         = selIdx;       /* 当前选择项索引 */
    item.defIdx         = defIdx;       /* 默认选择项索引 */
    item.showPriority   = showPriority; /* 显示优先级 */
    item.authority      = authority;    /* 显示优先级 */

    return item;
}

bool comparePriority(const ParaItem &item1, const ParaItem &item2)
{
    int pr1, pr2;
    pr1 = item1.showPriority;
    pr2 = item2.showPriority;
    if (pr1 < 0)
    {
        pr1 = 0;
    }
    if (pr2 < 0)
    {
        pr2 = 0;
    }

    return (pr1 < pr2);
}

//各个机型通用参数-软件设置参数
void initSoftwareParasList(QList <ParaItem> & parasList)
{
    //软件设置参数-语言；单位：无 ，范围0-1，默认0
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_SOFTWARESET,
                                   0 ,
                                   SET_LANGUAGE, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Language"),//语言
                                   0, 0, 5, 0, 0, "", "",
                                   QCoreApplication::translate("GLOBAL", "Chinese:0;English:1"),
                                   0, 0, 0x0002, operate));

    //软件设置参数---------------------------
}

//各个机型通用参数-时间设置参数
void initTimeParasList(QList <ParaItem> & parasList)
{
    //时间设置参数---------------------------
    //时间设置参数-年；单位：无 ，范围1000-9999，默认1000
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_TIMESET,
                                   0 ,
                                   1, 0, 0, PARA_VALUE_TYPE_INT,
                                   QCoreApplication::translate("GLOBAL", "Year"),//年
                                   1000, 1000, 9999, 1000, 0, "", "",
                                   "", 0, 0, 0x0000, operate));

    //时间设置参数-月；单位：无 ，范围1-12，默认1
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_TIMESET,
                                   0 ,
                                   2, 0, 0, PARA_VALUE_TYPE_INT,
                                   QCoreApplication::translate("GLOBAL", "Month"),//月
                                   1, 1, 12, 1, 0, "", "",
                                   "", 0, 0, 0x0001, operate));

    //时间设置参数-日；单位：无 ，范围1-31，默认1
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_TIMESET,
                                   0 ,
                                   3, 0, 0, PARA_VALUE_TYPE_INT,
                                   QCoreApplication::translate("GLOBAL", "Day"),//日
                                   1, 1, 31, 1, 0, "", "",
                                   "", 0, 0, 0x0002, operate));

    //时间设置参数-时；单位：无 ，范围0-23，默认0
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_TIMESET,
                                   0 ,
                                   4, 0, 0, PARA_VALUE_TYPE_INT,
                                   QCoreApplication::translate("GLOBAL", "Hour"),//时
                                   0, 0, 23, 0, 0, "", "",
                                   "", 0, 0, 0x0003, operate));

    //时间设置参数-分；单位：无 ，范围0-59，默认0
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_TIMESET,
                                   0 ,
                                   5, 0, 0, PARA_VALUE_TYPE_INT,
                                   QCoreApplication::translate("GLOBAL", "Minute"),//分
                                   0, 0, 59, 0, 0, "", "",
                                   "", 0, 0, 0x0004, operate));

    //时间设置参数-秒；单位：无 ，范围0-59，默认0
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_TIMESET,
                                   0 ,
                                   6, 0, 0, PARA_VALUE_TYPE_INT,
                                   QCoreApplication::translate("GLOBAL", "Second"),//秒
                                   0, 0, 59, 0, 0, "", "",
                                   "", 0, 0, 0x0005, operate));
    //时间设置参数---------------------------
}

//各个机型通用参数-网络管理参数
void initNetworkParasList(QList <ParaItem> & parasList)
{
    //网络管理参数-服务器IP设置；单位：无 ，范围无，默认192.168.16.253
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_NETWORKSET,
                                   0 ,
                                   SET_MACHINE_SERVERIP, 0, 0, PARA_VALUE_TYPE_STRINPUT,
                                   QCoreApplication::translate("GLOBAL", "Server IP settings"),//服务器IP设置
                                   0, 0, 0, 0, 0, "", "192.168.16.253",
                                   "",
                                   0, 0, 0x0007, operate));

    //网络管理参数-服务器端口设置；单位：无 ，范围0-65535，默认5000
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_NETWORKSET,
                                   0 ,
                                   SET_MACHINE_SERVERPORT, 0, 0, PARA_VALUE_TYPE_INT,
                                   QCoreApplication::translate("GLOBAL", "Server port settings"),//服务器端口设置
                                   5000, 0, U16_MAX, 5000, 0, "", "",
                                   "", 0, 0,0x0008, operate));

    //网络管理参数-本地IP设置；单位：无 ，范围无，默认192.168.16.41
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_NETWORKSET,
                                   0 ,
                                   SET_LOCALIP, 0, 0, PARA_VALUE_TYPE_STRINPUT,
                                   QCoreApplication::translate("GLOBAL", "Local IP settings"),//本地IP设置
                                   0, 0, 0, 0, 0, "", "192.168.16.100",
                                   "",
                                   0, 0, 0x0009, operate));

    //网络管理参数-本地端口设置；单位：无 ，范围0-65535，默认5001
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_NETWORKSET,
                                   0 ,
                                   SET_LOCALPORT, 0, 0, PARA_VALUE_TYPE_INT,
                                   QCoreApplication::translate("GLOBAL", "Local port settings"),//本地端口设置
                                   5001, 0, U16_MAX, 5001, 0, "", "",
                                   "", 0, 0,0x000A, operate));
    //网络管理参数---------------------------
}

OutCtrlItem makeAOutCtrlItem(int macType, int showPriority, QString name, int def, QString btn1Str, bool btn1Visible, int btn1ClickFun, int btn1PreFun, int btn1RelFun, QString btn2Str, bool btn2Visible, int btn2ClickFun, int btn2PreFun, int btn2RelFun, QString btn3Str, bool btn3Visible, int btn3ClickFun, int btn3PreFun, int btn3RelFun, QString btn4Str, bool btn4Visible, int btn4ClickFun, int btn4PreFun, int btn4RelFun, QString btn5Str, bool btn5Visible, int btn5ClickFun, int btn5PreFun, int btn5RelFun)
{
    OutCtrlItem item;
    item.clean();

    item.m_macType = macType;
    item.m_showPriority = showPriority;
    item.m_name = name;
    item.m_def  = def;

    item.m_btn1Str = btn1Str;
    item.m_btn1Visible = btn1Visible;
    item.m_btn1ClickFun = btn1ClickFun;
    item.m_btn1PreFun = btn1PreFun;
    item.m_btn1RelFun = btn1RelFun;

    item.m_btn2Str = btn2Str;
    item.m_btn2Visible = btn2Visible;
    item.m_btn2ClickFun = btn2ClickFun;
    item.m_btn2PreFun = btn2PreFun;
    item.m_btn2RelFun = btn2RelFun;

    item.m_btn3Str = btn3Str;
    item.m_btn3Visible = btn3Visible;
    item.m_btn3ClickFun = btn3ClickFun;
    item.m_btn3PreFun = btn3PreFun;
    item.m_btn3RelFun = btn3RelFun;

    item.m_btn4Str = btn4Str;
    item.m_btn4Visible = btn4Visible;
    item.m_btn4ClickFun = btn4ClickFun;
    item.m_btn4PreFun = btn4PreFun;
    item.m_btn4RelFun = btn4RelFun;

    item.m_btn5Str = btn5Str;
    item.m_btn5Visible = btn5Visible;
    item.m_btn5ClickFun = btn5ClickFun;
    item.m_btn5PreFun = btn5PreFun;
    item.m_btn5RelFun = btn5RelFun;

    return item;
}

ShortCutItem makeAShortCutItem(int macType, int showPriority, QString name, QString topImageName, int enumFunction)
{
    ShortCutItem item;
    item.clean();

    item.m_macType = macType;
    item.m_showPriority = showPriority;
    item.m_name = name;
    item.m_topImageName = topImageName;
    item.m_enumFunction = enumFunction;

    return item;
}

//添加辅助功能item
AssistItem makeAAssistItem(int macType, int showPriority, QString name, QString topImageName, int enumFunction)
{
    AssistItem item;
    item.clean();

    item.m_macType = macType;
    item.m_showPriority = showPriority;
    item.m_name = name;
    item.m_topImageName = topImageName;
    item.m_enumFunction = enumFunction;

    return item;
}

PatternSetItem makeAPatternSetItem(int macType, int showPriority, QString name, QString topImageName, int enumFunction)
{
    PatternSetItem item;
    item.clean();

    item.m_macType = macType;
    item.m_showPriority = showPriority;
    item.m_name = name;
    item.m_topImageName = topImageName;
    item.m_enumFunction = enumFunction;

    return item;
}

void initRootHMIConfigurationList(QList<ParaItem> &parasList)
{
    //超级用户界面配置参数-分辨率；单位：无
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_HMICONFIGURATION,
                                   0 ,
                                   ROOT_RESOLUTION, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Resolution"),//分辨率
                                   0, 0, 1, 0, 0, "", "",
                                   "1920x1080:0;1024x600:1",
                                   0, 0, 0x0001, root));

    //软件设置参数-通讯方式；单位：无 ，范围0-2，默认0
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_HMICONFIGURATION,
                                   0 ,
                                   SET_CONNECTMODE, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Communication method"),//通讯方式
                                   0, 0, 1, 0, 0, "", "",
                                   QCoreApplication::translate("GLOBAL", "Network:0;SerialPort:1"),//网口:0;串口:1
                                   0, 0, 0x0011, operate));

    //超级用户界面配置参数-机器类型；单位：无
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_HMICONFIGURATION,
                                   0 ,
                                   ROOT_MACTYPE, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Machine type"),//机器类型
                                   MACHINE_PUNCH, MACHINE_PUNCH, MACHINE_TEMPLATE_SEW, MACHINE_PUNCH, 0, "", "",
                                   ("000 " + QCoreApplication::translate("GLOBAL","PunchMachine:")+QString::number(MACHINE_PUNCH)+";"+//冲孔机
                                    "001 " + QCoreApplication::translate("GLOBAL","PunchSew:")+QString::number(MACHINE_PUNCH_SEW)+";"+//冲缝机
                                    "002 " + QCoreApplication::translate("GLOBAL","PunchMachineDZ:")+QString::number(MACHINE_PUNCH_AUTOPOS)+";"+//定制冲孔机 xcy 0902
                                    "003 " + QCoreApplication::translate("GLOBAL","AdhesivePress:")+QString::number(MACHINE_ADHESIVE)+";"+//压胶机
                                    "004 " + QCoreApplication::translate("GLOBAL","PunchSewEmb:")+QString::number(MACHINE_PUNCH_SEW_EMB)+";"+//冲绣缝
                                    "005 " + QCoreApplication::translate("GLOBAL","TemplateSew:")+QString::number(MACHINE_TEMPLATE_SEW)),//模板缝纫机
                                   0, 0, 0x0012, root));

    //超级用户界面配置参数-产品类型；单位：无
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_HMICONFIGURATION,
                                   0 ,
                                   ROOT_PRODUCTTYPE, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Product type"),//产品类型
                                   PRODUCT_PUNCH_SINGLEHEAD, PRODUCT_PUNCH_SINGLEHEAD, PRODUCT_NULL, PRODUCT_PUNCH_SINGLEHEAD, 0, "", "",
                                   (QCoreApplication::translate("GLOBAL","SingleHead:")+QString::number(PRODUCT_PUNCH_SINGLEHEAD)+";"+//单头
                                    QCoreApplication::translate("GLOBAL","DoubleleHead:")+QString::number(PRODUCT_PUNCH_TWOHEAD)+";"+//双头
                                    QCoreApplication::translate("GLOBAL","FourHead:")+QString::number(PRODUCT_PUNCH_FOURHEAD)+";"+//四头
                                    QCoreApplication::translate("GLOBAL","RotaryPunch:")+QString::number(PRODUCT_PUNCH_ROTARY)+";"+//旋转冲
                                    QCoreApplication::translate("GLOBAL","singleleHead:")+QString::number(PRODUCT_PUNCHSEW_SINGLEHEAD)+";"+//单头
                                    QCoreApplication::translate("GLOBAL","DoubleleHead:")+QString::number(PRODUCT_PUNCHSEW_TWOHEAD)+";"+//双头
                                    QCoreApplication::translate("GLOBAL","ProductNull:")+QString::number(PRODUCT_NULL)),//无
                                   0, 0, 0x0013, root));

    //超级用户界面配置参数-高低速切换；单位：无
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_HMICONFIGURATION,
                                   0 ,
                                   ROOT_HIGH_SPEED_SWITCHING, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "High and low speed switching"),//高低速切换
                                   1, 0, 1, 1, 0, "", "",
                                   "Low:0;High:1",
                                   1, 1, 0x0013, root));

    //超级用户界面配置参数-主背景是否带水印；单位：无
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_HMICONFIGURATION,
                                   0 ,
                                   ROOT_WATERMARKSET, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Is there a Richpeace logo"),//是否有富怡标志
                                   1, 0, 1, 1, 0, "", "",
                                   "No:0;Yes:1",
                                   1, 1, 0x0017, factory));

    //超级用户界面配置参数-是否带wifi；单位：无
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_HMICONFIGURATION,
                                   0 ,
                                   ROOT_WIFI, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Is it with WiFi"),//是否带wifi
                                   1, 0, 1, 1, 0, "", "",
                                   "No:0;Yes:1",
                                   1, 1, 0x0017, factory));

    //超级用户界面配置参数-参数是否分类显示；单位：无
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_HMICONFIGURATION,
                                   0 ,
                                   ROOT_PARASORTSET, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Parameter is classified"),//参数是否分类显示
                                   0, 0, 1, 0, 0, "", "",
                                   "No:0;Yes:1",
                                   0, 0, 0x0018, factory));

    //超级用户界面配置参数-界面解密；单位：无
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_HMICONFIGURATION,
                                   0 ,
                                   ROOT_HMIDECRYPT, 0, 0, PARA_VALUE_TYPE_CLICK,
                                   QCoreApplication::translate("GLOBAL", "HMI decrypt"),//界面解密
                                   0, 0, 0, 0, 0, "", "", "",
                                   0, 0, 0x0019, factory));

}

//物联网配置参数
void initRootIOTConfigurationList(QList<ParaItem> &parasList)
{
    //超级用户物联网配置-网关连接方式；单位：无
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_IOTCONFIGURATION,
                                   0 ,
                                   ROOT_GATEWAYCONNECTIONMETHOD, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Gateway connection method"),//网关连接方式
                                   0, 0, 2, 0, 0, "", "",
                                   QCoreApplication::translate("GLOBAL","Network port:0;Serial port:1"),//网口:0;串口:1
                                   0, 0, 0x0011, factory));

    //超级用户物联网配置-机架号输入; 单位:无
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_IOTCONFIGURATION,
                                   0 ,
                                   ROOT_RACKNUMBERINPUT, 0, 0, PARA_VALUE_TYPE_INT,
                                   QCoreApplication::translate("GLOBAL", "Input rack number"),//机架号输入
                                   111189, 0, INT_MAX, 111189, 0, "", "",
                                   "",
                                   0, 0, 0x0012, factory));

    //超级用户物联网配置-网络设置; 单位:无
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_IOTCONFIGURATION,
                                   0 ,
                                   ROOT_NETWORKSETTINGS, 0, 0, PARA_VALUE_TYPE_CLICK,
                                   QCoreApplication::translate("GLOBAL", "Network settings"),//网络设置
                                   0, 0, 0, 0, 0, "", "",
                                   "",
                                   0, 0, 0x0013, factory));

    //超级用户物联网配置-工厂预计交货时间; 单位:无
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_IOTCONFIGURATION,
                                   0 ,
                                   ROOT_DELIVERYTIME, 0, 0, PARA_VALUE_TYPE_STRINPUT,
                                   QCoreApplication::translate("GLOBAL", "Factory expects delivery time"),//工厂预计交货时间
                                   0, 0, 0, 0, 0, "", "",
                                   "",
                                   0, 0, 0x0014, factory));

    //超级用户物联网配置-调试进度; 单位:无
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_IOTCONFIGURATION,
                                   0 ,
                                   ROOT_DEBUGPROGRESS, 0, 0, PARA_VALUE_TYPE_INT,
                                   QCoreApplication::translate("GLOBAL", "Debugging progress"),//调试进度
                                   0, 1, 100, 0, 0, "", "",
                                   "",
                                   0, 0, 0x0015, factory));
}

ParaSetItem makeAParaSetItem(int macType, int showPriority, QString name, QString topImageName, int paraType)
{
    ParaSetItem item;
    item.clean();

    item.m_macType = macType;
    item.m_showPriority = showPriority;
    item.m_name = name;
    item.m_topImageName = topImageName;
    item.m_paraType = paraType;

    return item;
}

DebugItem makeADebugItem(int macType,int showPriority,QString name,QString topImageName,int enumFunction)
{
    DebugItem item;
    item.clean();

    item.m_macType = macType;
    item.m_showPriority = showPriority;
    item.m_name = name;
    item.m_topImageName = topImageName;
    item.m_enumFunction = enumFunction;

    return item;
}

SensorItem makeASensorItem(int byte, int bit, QString name, int type)
{
    SensorItem item;
    item.clean();

    item.m_byte_offset = byte;
    item.m_bit_offset = bit;
    item.m_name = name;
    item.m_type = type;

    return item;
}

ErrorCodeStateItem makeAErrorStateItem(int code, QString name)
{
    ErrorCodeStateItem item;
    item.clean();

    item.m_code = code;
    item.m_name = name;

    return item;
}

//冲孔机常用功能设置参数
void initPunchCommonFunParasList(QList<ParaItem> &parasList)
{
    //常用功能设置参数---------------------------
    //常用功能设置参数-常用按钮1；单位：无 ，范围全部，默认
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_COMMONFUN,
                                   0 ,
                                   1, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Frequently used button1"),//常用按钮1
                                   FUN_PATTERNSELECT, FUN_ALLTOZERO, FUN_NULL, FUN_PATTERNSELECT, 0, "", "",
                                   (QCoreApplication::translate("GLOBAL", "AllToZero:")+QString::number(FUN_ALLTOZERO)+";"+//全部归零
                                    QCoreApplication::translate("GLOBAL","SpindleJog:")+QString::number(FUN_PUNCHSPINDLEJOG)+";"+//主轴点动
                                    QCoreApplication::translate("GLOBAL","SpindleEnable:")+QString::number(FUN_SPINDLEENABLE)+";"+//主轴使能
                                    QCoreApplication::translate("GLOBAL","SpindleDisable:")+QString::number(FUN_SPINDLEDISABLE)+";"+//主轴失能
                                    QCoreApplication::translate("GLOBAL","SpindleTest:")+QString::number(FUN_SPINDLETEST)+";"+//主轴研车
                                    QCoreApplication::translate("GLOBAL","SetOffsetPoint:")+QString::number(FUN_SETOFFSETPOINT)+";"+//定偏移点
                                    QCoreApplication::translate("GLOBAL","BackOffsetPoint:")+QString::number(FUN_BACKOFFSETPOINT)+";"+//回偏移点
                                    QCoreApplication::translate("GLOBAL","SetStartPoint:")+QString::number(FUN_SETSTARTPOINT)+";"+//定起始点
                                    QCoreApplication::translate("GLOBAL","BackStartPoint:")+QString::number(FUN_BACKSTARTPOINT)+";"+//回起始点
                                    QCoreApplication::translate("GLOBAL","BackWorkPoint:")+QString::number(FUN_BACKWORKPOINT)+";"+//回工作点
                                    QCoreApplication::translate("GLOBAL","CheckFrame:")+QString::number(FUN_CHECKFRAME)+";"+//边框检查
                                    QCoreApplication::translate("GLOBAL","ManualColorChange:")+QString::number(FUN_PUNCHMANUALCHANGECOLOR)+";"+//手动换色
                                    QCoreApplication::translate("GLOBAL","ForwardOrBackward:")+QString::number(FUN_FORWARDORBACK)+";"+//前进回退
                                    QCoreApplication::translate("GLOBAL","ProcessReset:")+QString::number(FUN_PROCESSRESET)+";"+//流程复位
                                    QCoreApplication::translate("GLOBAL","SinglePunch:")+QString::number(FUN_SINGLEPUNCH)+";"+//单次冲孔
                                    QCoreApplication::translate("GLOBAL","FrameZero:")+QString::number(FUN_FRAMEZERO)+";"+//框架归零
                                    QCoreApplication::translate("GLOBAL","MoveToRightUp:")+QString::number(FUN_MOVETORIGHTUP)+";"+//去右上角
                                    QCoreApplication::translate("GLOBAL","MoveToRightDown:")+QString::number(FUN_MOVETORIGHTDOWN)+";"+//去右下角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftUp:")+QString::number(FUN_MOVETOLEFTUP)+";"+//去左上角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftDown:")+QString::number(FUN_MOVETOLEFTDOWN)+";"+//去左下角
                                    QCoreApplication::translate("GLOBAL","SetWorkRange:")+QString::number(FUN_SETWORKRANGE)+";"+//定工作范围
                                    QCoreApplication::translate("GLOBAL","PunchStopLower:")+QString::number(FUN_PUNCHSTOPLOWER)+";"+//冲头停下位
                                    QCoreApplication::translate("GLOBAL","PatternSelect:")+QString::number(FUN_PATTERNSELECT)+";"+//花样选择
                                    QCoreApplication::translate("GLOBAL","DrawOutline:")+QString::number(FUN_DRAWOUTLINE)+";"+//画轮廓线
                                    QCoreApplication::translate("GLOBAL","ToolDebug:")+QString::number(FUN_ROTATECOMPENSATE)+";"+//旋转补偿
                                    QCoreApplication::translate("GLOBAL","Null:")+QString::number(FUN_NULL)+";"),//无功能
                                   FUN_PATTERNSELECT, FUN_PATTERNSELECT, 0x0001, operate));

    //常用功能设置参数-常用按钮2；单位：无 ，范围全部，默认
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_COMMONFUN,
                                   0 ,
                                   2, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Frequently used button2"),//常用按钮2
                                   FUN_ALLTOZERO, FUN_ALLTOZERO, FUN_NULL, FUN_ALLTOZERO, 0, "", "",
                                   (QCoreApplication::translate("GLOBAL", "AllToZero:")+QString::number(FUN_ALLTOZERO)+";"+//全部归零
                                    QCoreApplication::translate("GLOBAL","SpindleJog:")+QString::number(FUN_PUNCHSPINDLEJOG)+";"+//主轴点动
                                    QCoreApplication::translate("GLOBAL","SpindleEnable:")+QString::number(FUN_SPINDLEENABLE)+";"+//主轴使能
                                    QCoreApplication::translate("GLOBAL","SpindleDisable:")+QString::number(FUN_SPINDLEDISABLE)+";"+//主轴失能
                                    QCoreApplication::translate("GLOBAL","SpindleTest:")+QString::number(FUN_SPINDLETEST)+";"+//主轴研车
                                    QCoreApplication::translate("GLOBAL","SetOffsetPoint:")+QString::number(FUN_SETOFFSETPOINT)+";"+//定偏移点
                                    QCoreApplication::translate("GLOBAL","BackOffsetPoint:")+QString::number(FUN_BACKOFFSETPOINT)+";"+//回偏移点
                                    QCoreApplication::translate("GLOBAL","SetStartPoint:")+QString::number(FUN_SETSTARTPOINT)+";"+//定起始点
                                    QCoreApplication::translate("GLOBAL","BackStartPoint:")+QString::number(FUN_BACKSTARTPOINT)+";"+//回起始点
                                    QCoreApplication::translate("GLOBAL","BackWorkPoint:")+QString::number(FUN_BACKWORKPOINT)+";"+//回工作点
                                    QCoreApplication::translate("GLOBAL","CheckFrame:")+QString::number(FUN_CHECKFRAME)+";"+//边框检查
                                    QCoreApplication::translate("GLOBAL","ManualColorChange:")+QString::number(FUN_PUNCHMANUALCHANGECOLOR)+";"+//手动换色
                                    QCoreApplication::translate("GLOBAL","ForwardOrBackward:")+QString::number(FUN_FORWARDORBACK)+";"+//前进回退
                                    QCoreApplication::translate("GLOBAL","ProcessReset:")+QString::number(FUN_PROCESSRESET)+";"+//流程复位
                                    QCoreApplication::translate("GLOBAL","SinglePunch:")+QString::number(FUN_SINGLEPUNCH)+";"+//单次冲孔
                                    QCoreApplication::translate("GLOBAL","FrameZero:")+QString::number(FUN_FRAMEZERO)+";"+//框架归零
                                    QCoreApplication::translate("GLOBAL","MoveToRightUp:")+QString::number(FUN_MOVETORIGHTUP)+";"+//去右上角
                                    QCoreApplication::translate("GLOBAL","MoveToRightDown:")+QString::number(FUN_MOVETORIGHTDOWN)+";"+//去右下角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftUp:")+QString::number(FUN_MOVETOLEFTUP)+";"+//去左上角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftDown:")+QString::number(FUN_MOVETOLEFTDOWN)+";"+//去左下角
                                    QCoreApplication::translate("GLOBAL","SetWorkRange:")+QString::number(FUN_SETWORKRANGE)+";"+//定工作范围
                                    QCoreApplication::translate("GLOBAL","PunchStopLower:")+QString::number(FUN_PUNCHSTOPLOWER)+";"+//冲头停下位
                                    QCoreApplication::translate("GLOBAL","PatternSelect:")+QString::number(FUN_PATTERNSELECT)+";"+//花样选择
                                    QCoreApplication::translate("GLOBAL","DrawOutline:")+QString::number(FUN_DRAWOUTLINE)+";"+//画轮廓线
                                    QCoreApplication::translate("GLOBAL","ToolDebug:")+QString::number(FUN_ROTATECOMPENSATE)+";"+//旋转补偿
                                    QCoreApplication::translate("GLOBAL","Null:")+QString::number(FUN_NULL)+";"),//无功能
                                   //                                    QCoreApplication::translate("GLOBAL","SewTest:")+QString::number(FUN_SEWSPINDLETEST)+";"+//缝纫主轴研车
                                   FUN_ALLTOZERO, FUN_ALLTOZERO, 0x0002, operate));

    //常用功能设置参数-常用按钮3；单位：无 ，范围全部，默认
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_COMMONFUN,
                                   0 ,
                                   3, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Frequently used button3"),//常用按钮3
                                   FUN_PUNCHSPINDLEJOG, FUN_ALLTOZERO, FUN_NULL, FUN_PUNCHSPINDLEJOG, 0, "", "",
                                   (QCoreApplication::translate("GLOBAL", "AllToZero:")+QString::number(FUN_ALLTOZERO)+";"+//全部归零
                                    QCoreApplication::translate("GLOBAL","SpindleJog:")+QString::number(FUN_PUNCHSPINDLEJOG)+";"+//主轴点动
                                    QCoreApplication::translate("GLOBAL","SpindleEnable:")+QString::number(FUN_SPINDLEENABLE)+";"+//主轴使能
                                    QCoreApplication::translate("GLOBAL","SpindleDisable:")+QString::number(FUN_SPINDLEDISABLE)+";"+//主轴失能
                                    QCoreApplication::translate("GLOBAL","SpindleTest:")+QString::number(FUN_SPINDLETEST)+";"+//主轴研车
                                    QCoreApplication::translate("GLOBAL","SetOffsetPoint:")+QString::number(FUN_SETOFFSETPOINT)+";"+//定偏移点
                                    QCoreApplication::translate("GLOBAL","BackOffsetPoint:")+QString::number(FUN_BACKOFFSETPOINT)+";"+//回偏移点
                                    QCoreApplication::translate("GLOBAL","SetStartPoint:")+QString::number(FUN_SETSTARTPOINT)+";"+//定起始点
                                    QCoreApplication::translate("GLOBAL","BackStartPoint:")+QString::number(FUN_BACKSTARTPOINT)+";"+//回起始点
                                    QCoreApplication::translate("GLOBAL","BackWorkPoint:")+QString::number(FUN_BACKWORKPOINT)+";"+//回工作点
                                    QCoreApplication::translate("GLOBAL","CheckFrame:")+QString::number(FUN_CHECKFRAME)+";"+//边框检查
                                    QCoreApplication::translate("GLOBAL","ManualColorChange:")+QString::number(FUN_PUNCHMANUALCHANGECOLOR)+";"+//手动换色
                                    QCoreApplication::translate("GLOBAL","ForwardOrBackward:")+QString::number(FUN_FORWARDORBACK)+";"+//前进回退
                                    QCoreApplication::translate("GLOBAL","ProcessReset:")+QString::number(FUN_PROCESSRESET)+";"+//流程复位
                                    QCoreApplication::translate("GLOBAL","SinglePunch:")+QString::number(FUN_SINGLEPUNCH)+";"+//单次冲孔
                                    QCoreApplication::translate("GLOBAL","FrameZero:")+QString::number(FUN_FRAMEZERO)+";"+//框架归零
                                    QCoreApplication::translate("GLOBAL","MoveToRightUp:")+QString::number(FUN_MOVETORIGHTUP)+";"+//去右上角
                                    QCoreApplication::translate("GLOBAL","MoveToRightDown:")+QString::number(FUN_MOVETORIGHTDOWN)+";"+//去右下角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftUp:")+QString::number(FUN_MOVETOLEFTUP)+";"+//去左上角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftDown:")+QString::number(FUN_MOVETOLEFTDOWN)+";"+//去左下角
                                    QCoreApplication::translate("GLOBAL","SetWorkRange:")+QString::number(FUN_SETWORKRANGE)+";"+//定工作范围
                                    QCoreApplication::translate("GLOBAL","PunchStopLower:")+QString::number(FUN_PUNCHSTOPLOWER)+";"+//冲头停下位
                                    QCoreApplication::translate("GLOBAL","PatternSelect:")+QString::number(FUN_PATTERNSELECT)+";"+//花样选择
                                    QCoreApplication::translate("GLOBAL","DrawOutline:")+QString::number(FUN_DRAWOUTLINE)+";"+//画轮廓线
                                    QCoreApplication::translate("GLOBAL","ToolDebug:")+QString::number(FUN_ROTATECOMPENSATE)+";"+//旋转补偿
                                    QCoreApplication::translate("GLOBAL","Null:")+QString::number(FUN_NULL)+";"),//无功能
                                   FUN_PUNCHSPINDLEJOG, FUN_PUNCHSPINDLEJOG, 0x0003, operate));

    //常用功能设置参数-常用按钮4；单位：无 ，范围全部，默认
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_COMMONFUN,
                                   0 ,
                                   4, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Frequently used button4"),//常用按钮4
                                   FUN_SETSTARTPOINT, FUN_ALLTOZERO, FUN_NULL, FUN_SETSTARTPOINT, 0, "", "",
                                   (QCoreApplication::translate("GLOBAL", "AllToZero:")+QString::number(FUN_ALLTOZERO)+";"+//全部归零
                                    QCoreApplication::translate("GLOBAL","SpindleJog:")+QString::number(FUN_PUNCHSPINDLEJOG)+";"+//主轴点动
                                    QCoreApplication::translate("GLOBAL","SpindleEnable:")+QString::number(FUN_SPINDLEENABLE)+";"+//主轴使能
                                    QCoreApplication::translate("GLOBAL","SpindleDisable:")+QString::number(FUN_SPINDLEDISABLE)+";"+//主轴失能
                                    QCoreApplication::translate("GLOBAL","SpindleTest:")+QString::number(FUN_SPINDLETEST)+";"+//主轴研车
                                    QCoreApplication::translate("GLOBAL","SetOffsetPoint:")+QString::number(FUN_SETOFFSETPOINT)+";"+//定偏移点
                                    QCoreApplication::translate("GLOBAL","BackOffsetPoint:")+QString::number(FUN_BACKOFFSETPOINT)+";"+//回偏移点
                                    QCoreApplication::translate("GLOBAL","SetStartPoint:")+QString::number(FUN_SETSTARTPOINT)+";"+//定起始点
                                    QCoreApplication::translate("GLOBAL","BackStartPoint:")+QString::number(FUN_BACKSTARTPOINT)+";"+//回起始点
                                    QCoreApplication::translate("GLOBAL","BackWorkPoint:")+QString::number(FUN_BACKWORKPOINT)+";"+//回工作点
                                    QCoreApplication::translate("GLOBAL","CheckFrame:")+QString::number(FUN_CHECKFRAME)+";"+//边框检查
                                    QCoreApplication::translate("GLOBAL","ManualColorChange:")+QString::number(FUN_PUNCHMANUALCHANGECOLOR)+";"+//手动换色
                                    QCoreApplication::translate("GLOBAL","ForwardOrBackward:")+QString::number(FUN_FORWARDORBACK)+";"+//前进回退
                                    QCoreApplication::translate("GLOBAL","ProcessReset:")+QString::number(FUN_PROCESSRESET)+";"+//流程复位
                                    QCoreApplication::translate("GLOBAL","SinglePunch:")+QString::number(FUN_SINGLEPUNCH)+";"+//单次冲孔
                                    QCoreApplication::translate("GLOBAL","FrameZero:")+QString::number(FUN_FRAMEZERO)+";"+//框架归零
                                    QCoreApplication::translate("GLOBAL","MoveToRightUp:")+QString::number(FUN_MOVETORIGHTUP)+";"+//去右上角
                                    QCoreApplication::translate("GLOBAL","MoveToRightDown:")+QString::number(FUN_MOVETORIGHTDOWN)+";"+//去右下角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftUp:")+QString::number(FUN_MOVETOLEFTUP)+";"+//去左上角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftDown:")+QString::number(FUN_MOVETOLEFTDOWN)+";"+//去左下角
                                    QCoreApplication::translate("GLOBAL","SetWorkRange:")+QString::number(FUN_SETWORKRANGE)+";"+//定工作范围
                                    QCoreApplication::translate("GLOBAL","PunchStopLower:")+QString::number(FUN_PUNCHSTOPLOWER)+";"+//冲头停下位
                                    QCoreApplication::translate("GLOBAL","PatternSelect:")+QString::number(FUN_PATTERNSELECT)+";"+//花样选择
                                    QCoreApplication::translate("GLOBAL","DrawOutline:")+QString::number(FUN_DRAWOUTLINE)+";"+//画轮廓线
                                    QCoreApplication::translate("GLOBAL","ToolDebug:")+QString::number(FUN_ROTATECOMPENSATE)+";"+//旋转补偿
                                    QCoreApplication::translate("GLOBAL","Null:")+QString::number(FUN_NULL)+";"),//无功能
                                   FUN_SETSTARTPOINT, FUN_SETSTARTPOINT, 0x0004, operate));

    //常用功能设置参数-常用按钮5；单位：无 ，范围全部，默认
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_COMMONFUN,
                                   0 ,
                                   5, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Frequently used button5"),//常用按钮5
                                   FUN_BACKSTARTPOINT, FUN_ALLTOZERO, FUN_NULL, FUN_BACKSTARTPOINT, 0, "", "",
                                   (QCoreApplication::translate("GLOBAL", "AllToZero:")+QString::number(FUN_ALLTOZERO)+";"+//全部归零
                                    QCoreApplication::translate("GLOBAL","SpindleJog:")+QString::number(FUN_PUNCHSPINDLEJOG)+";"+//主轴点动
                                    QCoreApplication::translate("GLOBAL","SpindleEnable:")+QString::number(FUN_SPINDLEENABLE)+";"+//主轴使能
                                    QCoreApplication::translate("GLOBAL","SpindleDisable:")+QString::number(FUN_SPINDLEDISABLE)+";"+//主轴失能
                                    QCoreApplication::translate("GLOBAL","SpindleTest:")+QString::number(FUN_SPINDLETEST)+";"+//主轴研车
                                    QCoreApplication::translate("GLOBAL","SetOffsetPoint:")+QString::number(FUN_SETOFFSETPOINT)+";"+//定偏移点
                                    QCoreApplication::translate("GLOBAL","BackOffsetPoint:")+QString::number(FUN_BACKOFFSETPOINT)+";"+//回偏移点
                                    QCoreApplication::translate("GLOBAL","SetStartPoint:")+QString::number(FUN_SETSTARTPOINT)+";"+//定起始点
                                    QCoreApplication::translate("GLOBAL","BackStartPoint:")+QString::number(FUN_BACKSTARTPOINT)+";"+//回起始点
                                    QCoreApplication::translate("GLOBAL","BackWorkPoint:")+QString::number(FUN_BACKWORKPOINT)+";"+//回工作点
                                    QCoreApplication::translate("GLOBAL","CheckFrame:")+QString::number(FUN_CHECKFRAME)+";"+//边框检查
                                    QCoreApplication::translate("GLOBAL","ManualColorChange:")+QString::number(FUN_PUNCHMANUALCHANGECOLOR)+";"+//手动换色
                                    QCoreApplication::translate("GLOBAL","ForwardOrBackward:")+QString::number(FUN_FORWARDORBACK)+";"+//前进回退
                                    QCoreApplication::translate("GLOBAL","ProcessReset:")+QString::number(FUN_PROCESSRESET)+";"+//流程复位
                                    QCoreApplication::translate("GLOBAL","SinglePunch:")+QString::number(FUN_SINGLEPUNCH)+";"+//单次冲孔
                                    QCoreApplication::translate("GLOBAL","FrameZero:")+QString::number(FUN_FRAMEZERO)+";"+//框架归零
                                    QCoreApplication::translate("GLOBAL","MoveToRightUp:")+QString::number(FUN_MOVETORIGHTUP)+";"+//去右上角
                                    QCoreApplication::translate("GLOBAL","MoveToRightDown:")+QString::number(FUN_MOVETORIGHTDOWN)+";"+//去右下角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftUp:")+QString::number(FUN_MOVETOLEFTUP)+";"+//去左上角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftDown:")+QString::number(FUN_MOVETOLEFTDOWN)+";"+//去左下角
                                    QCoreApplication::translate("GLOBAL","SetWorkRange:")+QString::number(FUN_SETWORKRANGE)+";"+//定工作范围
                                    QCoreApplication::translate("GLOBAL","PunchStopLower:")+QString::number(FUN_PUNCHSTOPLOWER)+";"+//冲头停下位
                                    QCoreApplication::translate("GLOBAL","PatternSelect:")+QString::number(FUN_PATTERNSELECT)+";"+//花样选择
                                    QCoreApplication::translate("GLOBAL","DrawOutline:")+QString::number(FUN_DRAWOUTLINE)+";"+//画轮廓线
                                    QCoreApplication::translate("GLOBAL","ToolDebug:")+QString::number(FUN_ROTATECOMPENSATE)+";"+//旋转补偿
                                    QCoreApplication::translate("GLOBAL","Null:")+QString::number(FUN_NULL)+";"),//无功能
                                   FUN_BACKSTARTPOINT, FUN_BACKSTARTPOINT, 0x0005, operate));

    //常用功能设置参数-常用按钮6；单位：无 ，范围全部，默认
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_COMMONFUN,
                                   0 ,
                                   6, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Frequently used button6"),//常用按钮6
                                   FUN_BACKWORKPOINT, FUN_ALLTOZERO, FUN_NULL, FUN_BACKWORKPOINT, 0, "", "",
                                   (QCoreApplication::translate("GLOBAL", "AllToZero:")+QString::number(FUN_ALLTOZERO)+";"+//全部归零
                                    QCoreApplication::translate("GLOBAL","SpindleJog:")+QString::number(FUN_PUNCHSPINDLEJOG)+";"+//主轴点动
                                    QCoreApplication::translate("GLOBAL","SpindleEnable:")+QString::number(FUN_SPINDLEENABLE)+";"+//主轴使能
                                    QCoreApplication::translate("GLOBAL","SpindleDisable:")+QString::number(FUN_SPINDLEDISABLE)+";"+//主轴失能
                                    QCoreApplication::translate("GLOBAL","SpindleTest:")+QString::number(FUN_SPINDLETEST)+";"+//主轴研车
                                    QCoreApplication::translate("GLOBAL","SetOffsetPoint:")+QString::number(FUN_SETOFFSETPOINT)+";"+//定偏移点
                                    QCoreApplication::translate("GLOBAL","BackOffsetPoint:")+QString::number(FUN_BACKOFFSETPOINT)+";"+//回偏移点
                                    QCoreApplication::translate("GLOBAL","SetStartPoint:")+QString::number(FUN_SETSTARTPOINT)+";"+//定起始点
                                    QCoreApplication::translate("GLOBAL","BackStartPoint:")+QString::number(FUN_BACKSTARTPOINT)+";"+//回起始点
                                    QCoreApplication::translate("GLOBAL","BackWorkPoint:")+QString::number(FUN_BACKWORKPOINT)+";"+//回工作点
                                    QCoreApplication::translate("GLOBAL","CheckFrame:")+QString::number(FUN_CHECKFRAME)+";"+//边框检查
                                    QCoreApplication::translate("GLOBAL","ManualColorChange:")+QString::number(FUN_PUNCHMANUALCHANGECOLOR)+";"+//手动换色
                                    QCoreApplication::translate("GLOBAL","ForwardOrBackward:")+QString::number(FUN_FORWARDORBACK)+";"+//前进回退
                                    QCoreApplication::translate("GLOBAL","ProcessReset:")+QString::number(FUN_PROCESSRESET)+";"+//流程复位
                                    QCoreApplication::translate("GLOBAL","SinglePunch:")+QString::number(FUN_SINGLEPUNCH)+";"+//单次冲孔
                                    QCoreApplication::translate("GLOBAL","FrameZero:")+QString::number(FUN_FRAMEZERO)+";"+//框架归零
                                    QCoreApplication::translate("GLOBAL","MoveToRightUp:")+QString::number(FUN_MOVETORIGHTUP)+";"+//去右上角
                                    QCoreApplication::translate("GLOBAL","MoveToRightDown:")+QString::number(FUN_MOVETORIGHTDOWN)+";"+//去右下角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftUp:")+QString::number(FUN_MOVETOLEFTUP)+";"+//去左上角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftDown:")+QString::number(FUN_MOVETOLEFTDOWN)+";"+//去左下角
                                    QCoreApplication::translate("GLOBAL","SetWorkRange:")+QString::number(FUN_SETWORKRANGE)+";"+//定工作范围
                                    QCoreApplication::translate("GLOBAL","PunchStopLower:")+QString::number(FUN_PUNCHSTOPLOWER)+";"+//冲头停下位
                                    QCoreApplication::translate("GLOBAL","PatternSelect:")+QString::number(FUN_PATTERNSELECT)+";"+//花样选择
                                    QCoreApplication::translate("GLOBAL","DrawOutline:")+QString::number(FUN_DRAWOUTLINE)+";"+//画轮廓线
                                    QCoreApplication::translate("GLOBAL","ToolDebug:")+QString::number(FUN_ROTATECOMPENSATE)+";"+//旋转补偿
                                    QCoreApplication::translate("GLOBAL","Null:")+QString::number(FUN_NULL)+";"),//无功能
                                   FUN_BACKWORKPOINT, FUN_BACKWORKPOINT, 0x0006, operate));

    //常用功能设置参数-常用按钮7；单位：无 ，范围全部，默认
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_COMMONFUN,
                                   0 ,
                                   7, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Frequently used button7"),//常用按钮7
                                   FUN_CHECKFRAME, FUN_ALLTOZERO, FUN_NULL, FUN_CHECKFRAME, 0, "", "",
                                   (QCoreApplication::translate("GLOBAL", "AllToZero:")+QString::number(FUN_ALLTOZERO)+";"+//全部归零
                                    QCoreApplication::translate("GLOBAL","SpindleJog:")+QString::number(FUN_PUNCHSPINDLEJOG)+";"+//主轴点动
                                    QCoreApplication::translate("GLOBAL","SpindleEnable:")+QString::number(FUN_SPINDLEENABLE)+";"+//主轴使能
                                    QCoreApplication::translate("GLOBAL","SpindleDisable:")+QString::number(FUN_SPINDLEDISABLE)+";"+//主轴失能
                                    QCoreApplication::translate("GLOBAL","SpindleTest:")+QString::number(FUN_SPINDLETEST)+";"+//主轴研车
                                    QCoreApplication::translate("GLOBAL","SetOffsetPoint:")+QString::number(FUN_SETOFFSETPOINT)+";"+//定偏移点
                                    QCoreApplication::translate("GLOBAL","BackOffsetPoint:")+QString::number(FUN_BACKOFFSETPOINT)+";"+//回偏移点
                                    QCoreApplication::translate("GLOBAL","SetStartPoint:")+QString::number(FUN_SETSTARTPOINT)+";"+//定起始点
                                    QCoreApplication::translate("GLOBAL","BackStartPoint:")+QString::number(FUN_BACKSTARTPOINT)+";"+//回起始点
                                    QCoreApplication::translate("GLOBAL","BackWorkPoint:")+QString::number(FUN_BACKWORKPOINT)+";"+//回工作点
                                    QCoreApplication::translate("GLOBAL","CheckFrame:")+QString::number(FUN_CHECKFRAME)+";"+//边框检查
                                    QCoreApplication::translate("GLOBAL","ManualColorChange:")+QString::number(FUN_PUNCHMANUALCHANGECOLOR)+";"+//手动换色
                                    QCoreApplication::translate("GLOBAL","ForwardOrBackward:")+QString::number(FUN_FORWARDORBACK)+";"+//前进回退
                                    QCoreApplication::translate("GLOBAL","ProcessReset:")+QString::number(FUN_PROCESSRESET)+";"+//流程复位
                                    QCoreApplication::translate("GLOBAL","SinglePunch:")+QString::number(FUN_SINGLEPUNCH)+";"+//单次冲孔
                                    QCoreApplication::translate("GLOBAL","FrameZero:")+QString::number(FUN_FRAMEZERO)+";"+//框架归零
                                    QCoreApplication::translate("GLOBAL","MoveToRightUp:")+QString::number(FUN_MOVETORIGHTUP)+";"+//去右上角
                                    QCoreApplication::translate("GLOBAL","MoveToRightDown:")+QString::number(FUN_MOVETORIGHTDOWN)+";"+//去右下角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftUp:")+QString::number(FUN_MOVETOLEFTUP)+";"+//去左上角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftDown:")+QString::number(FUN_MOVETOLEFTDOWN)+";"+//去左下角
                                    QCoreApplication::translate("GLOBAL","SetWorkRange:")+QString::number(FUN_SETWORKRANGE)+";"+//定工作范围
                                    QCoreApplication::translate("GLOBAL","PunchStopLower:")+QString::number(FUN_PUNCHSTOPLOWER)+";"+//冲头停下位
                                    QCoreApplication::translate("GLOBAL","PatternSelect:")+QString::number(FUN_PATTERNSELECT)+";"+//花样选择
                                    QCoreApplication::translate("GLOBAL","DrawOutline:")+QString::number(FUN_DRAWOUTLINE)+";"+//画轮廓线
                                    QCoreApplication::translate("GLOBAL","ToolDebug:")+QString::number(FUN_ROTATECOMPENSATE)+";"+//旋转补偿
                                    QCoreApplication::translate("GLOBAL","Null:")+QString::number(FUN_NULL)+";"),//无功能
                                   FUN_CHECKFRAME, FUN_CHECKFRAME, 0x0007, operate));

    //常用功能设置参数-常用按钮8；单位：无 ，范围全部，默认
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_COMMONFUN,
                                   0 ,
                                   8, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Frequently used button8"),//常用按钮8
                                   FUN_PUNCHMANUALCHANGECOLOR, FUN_ALLTOZERO, FUN_NULL, FUN_PUNCHMANUALCHANGECOLOR, 0, "", "",
                                   (QCoreApplication::translate("GLOBAL", "AllToZero:")+QString::number(FUN_ALLTOZERO)+";"+//全部归零
                                    QCoreApplication::translate("GLOBAL","SpindleJog:")+QString::number(FUN_PUNCHSPINDLEJOG)+";"+//主轴点动
                                    QCoreApplication::translate("GLOBAL","SpindleEnable:")+QString::number(FUN_SPINDLEENABLE)+";"+//主轴使能
                                    QCoreApplication::translate("GLOBAL","SpindleDisable:")+QString::number(FUN_SPINDLEDISABLE)+";"+//主轴失能
                                    QCoreApplication::translate("GLOBAL","SpindleTest:")+QString::number(FUN_SPINDLETEST)+";"+//主轴研车
                                    QCoreApplication::translate("GLOBAL","SetOffsetPoint:")+QString::number(FUN_SETOFFSETPOINT)+";"+//定偏移点
                                    QCoreApplication::translate("GLOBAL","BackOffsetPoint:")+QString::number(FUN_BACKOFFSETPOINT)+";"+//回偏移点
                                    QCoreApplication::translate("GLOBAL","SetStartPoint:")+QString::number(FUN_SETSTARTPOINT)+";"+//定起始点
                                    QCoreApplication::translate("GLOBAL","BackStartPoint:")+QString::number(FUN_BACKSTARTPOINT)+";"+//回起始点
                                    QCoreApplication::translate("GLOBAL","BackWorkPoint:")+QString::number(FUN_BACKWORKPOINT)+";"+//回工作点
                                    QCoreApplication::translate("GLOBAL","CheckFrame:")+QString::number(FUN_CHECKFRAME)+";"+//边框检查
                                    QCoreApplication::translate("GLOBAL","ManualColorChange:")+QString::number(FUN_PUNCHMANUALCHANGECOLOR)+";"+//手动换色
                                    QCoreApplication::translate("GLOBAL","ForwardOrBackward:")+QString::number(FUN_FORWARDORBACK)+";"+//前进回退
                                    QCoreApplication::translate("GLOBAL","ProcessReset:")+QString::number(FUN_PROCESSRESET)+";"+//流程复位
                                    QCoreApplication::translate("GLOBAL","SinglePunch:")+QString::number(FUN_SINGLEPUNCH)+";"+//单次冲孔
                                    QCoreApplication::translate("GLOBAL","FrameZero:")+QString::number(FUN_FRAMEZERO)+";"+//框架归零
                                    QCoreApplication::translate("GLOBAL","MoveToRightUp:")+QString::number(FUN_MOVETORIGHTUP)+";"+//去右上角
                                    QCoreApplication::translate("GLOBAL","MoveToRightDown:")+QString::number(FUN_MOVETORIGHTDOWN)+";"+//去右下角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftUp:")+QString::number(FUN_MOVETOLEFTUP)+";"+//去左上角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftDown:")+QString::number(FUN_MOVETOLEFTDOWN)+";"+//去左下角
                                    QCoreApplication::translate("GLOBAL","SetWorkRange:")+QString::number(FUN_SETWORKRANGE)+";"+//定工作范围
                                    QCoreApplication::translate("GLOBAL","PunchStopLower:")+QString::number(FUN_PUNCHSTOPLOWER)+";"+//冲头停下位
                                    QCoreApplication::translate("GLOBAL","PatternSelect:")+QString::number(FUN_PATTERNSELECT)+";"+//花样选择
                                    QCoreApplication::translate("GLOBAL","DrawOutline:")+QString::number(FUN_DRAWOUTLINE)+";"+//画轮廓线
                                    QCoreApplication::translate("GLOBAL","ToolDebug:")+QString::number(FUN_ROTATECOMPENSATE)+";"+//旋转补偿
                                    QCoreApplication::translate("GLOBAL","Null:")+QString::number(FUN_NULL)+";"),//无功能
                                   FUN_PUNCHMANUALCHANGECOLOR, FUN_PUNCHMANUALCHANGECOLOR, 0x0008, operate));

    //常用功能设置参数-常用按钮9；单位：无 ，范围全部，默认
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_COMMONFUN,
                                   0 ,
                                   9, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Frequently used button9"),//常用按钮9
                                   FUN_PROCESSRESET, FUN_ALLTOZERO, FUN_NULL, FUN_PROCESSRESET, 0, "", "",
                                   (QCoreApplication::translate("GLOBAL", "AllToZero:")+QString::number(FUN_ALLTOZERO)+";"+//全部归零
                                    QCoreApplication::translate("GLOBAL","SpindleJog:")+QString::number(FUN_PUNCHSPINDLEJOG)+";"+//主轴点动
                                    QCoreApplication::translate("GLOBAL","SpindleEnable:")+QString::number(FUN_SPINDLEENABLE)+";"+//主轴使能
                                    QCoreApplication::translate("GLOBAL","SpindleDisable:")+QString::number(FUN_SPINDLEDISABLE)+";"+//主轴失能
                                    QCoreApplication::translate("GLOBAL","SpindleTest:")+QString::number(FUN_SPINDLETEST)+";"+//主轴研车
                                    QCoreApplication::translate("GLOBAL","SetOffsetPoint:")+QString::number(FUN_SETOFFSETPOINT)+";"+//定偏移点
                                    QCoreApplication::translate("GLOBAL","BackOffsetPoint:")+QString::number(FUN_BACKOFFSETPOINT)+";"+//回偏移点
                                    QCoreApplication::translate("GLOBAL","SetStartPoint:")+QString::number(FUN_SETSTARTPOINT)+";"+//定起始点
                                    QCoreApplication::translate("GLOBAL","BackStartPoint:")+QString::number(FUN_BACKSTARTPOINT)+";"+//回起始点
                                    QCoreApplication::translate("GLOBAL","BackWorkPoint:")+QString::number(FUN_BACKWORKPOINT)+";"+//回工作点
                                    QCoreApplication::translate("GLOBAL","CheckFrame:")+QString::number(FUN_CHECKFRAME)+";"+//边框检查
                                    QCoreApplication::translate("GLOBAL","ManualColorChange:")+QString::number(FUN_PUNCHMANUALCHANGECOLOR)+";"+//手动换色
                                    QCoreApplication::translate("GLOBAL","ForwardOrBackward:")+QString::number(FUN_FORWARDORBACK)+";"+//前进回退
                                    QCoreApplication::translate("GLOBAL","ProcessReset:")+QString::number(FUN_PROCESSRESET)+";"+//流程复位
                                    QCoreApplication::translate("GLOBAL","SinglePunch:")+QString::number(FUN_SINGLEPUNCH)+";"+//单次冲孔
                                    QCoreApplication::translate("GLOBAL","FrameZero:")+QString::number(FUN_FRAMEZERO)+";"+//框架归零
                                    QCoreApplication::translate("GLOBAL","MoveToRightUp:")+QString::number(FUN_MOVETORIGHTUP)+";"+//去右上角
                                    QCoreApplication::translate("GLOBAL","MoveToRightDown:")+QString::number(FUN_MOVETORIGHTDOWN)+";"+//去右下角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftUp:")+QString::number(FUN_MOVETOLEFTUP)+";"+//去左上角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftDown:")+QString::number(FUN_MOVETOLEFTDOWN)+";"+//去左下角
                                    QCoreApplication::translate("GLOBAL","SetWorkRange:")+QString::number(FUN_SETWORKRANGE)+";"+//定工作范围
                                    QCoreApplication::translate("GLOBAL","PunchStopLower:")+QString::number(FUN_PUNCHSTOPLOWER)+";"+//冲头停下位
                                    QCoreApplication::translate("GLOBAL","PatternSelect:")+QString::number(FUN_PATTERNSELECT)+";"+//花样选择
                                    QCoreApplication::translate("GLOBAL","DrawOutline:")+QString::number(FUN_DRAWOUTLINE)+";"+//画轮廓线
                                    QCoreApplication::translate("GLOBAL","ToolDebug:")+QString::number(FUN_ROTATECOMPENSATE)+";"+//旋转补偿
                                    QCoreApplication::translate("GLOBAL","Null:")+QString::number(FUN_NULL)+";"),//无功能
                                   FUN_PROCESSRESET, FUN_PROCESSRESET, 0x0009, operate));

    //常用功能设置参数-常用按钮10；单位：无 ，范围全部，默认
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_COMMONFUN,
                                   0 ,
                                   10, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Frequently used button10"),//常用按钮10
                                   FUN_DRAWOUTLINE, FUN_ALLTOZERO, FUN_NULL, FUN_DRAWOUTLINE, 0, "", "",
                                   (QCoreApplication::translate("GLOBAL", "AllToZero:")+QString::number(FUN_ALLTOZERO)+";"+//全部归零
                                    QCoreApplication::translate("GLOBAL","SpindleJog:")+QString::number(FUN_PUNCHSPINDLEJOG)+";"+//主轴点动
                                    QCoreApplication::translate("GLOBAL","SpindleEnable:")+QString::number(FUN_SPINDLEENABLE)+";"+//主轴使能
                                    QCoreApplication::translate("GLOBAL","SpindleDisable:")+QString::number(FUN_SPINDLEDISABLE)+";"+//主轴失能
                                    QCoreApplication::translate("GLOBAL","SpindleTest:")+QString::number(FUN_SPINDLETEST)+";"+//主轴研车
                                    QCoreApplication::translate("GLOBAL","SetOffsetPoint:")+QString::number(FUN_SETOFFSETPOINT)+";"+//定偏移点
                                    QCoreApplication::translate("GLOBAL","BackOffsetPoint:")+QString::number(FUN_BACKOFFSETPOINT)+";"+//回偏移点
                                    QCoreApplication::translate("GLOBAL","SetStartPoint:")+QString::number(FUN_SETSTARTPOINT)+";"+//定起始点
                                    QCoreApplication::translate("GLOBAL","BackStartPoint:")+QString::number(FUN_BACKSTARTPOINT)+";"+//回起始点
                                    QCoreApplication::translate("GLOBAL","BackWorkPoint:")+QString::number(FUN_BACKWORKPOINT)+";"+//回工作点
                                    QCoreApplication::translate("GLOBAL","CheckFrame:")+QString::number(FUN_CHECKFRAME)+";"+//边框检查
                                    QCoreApplication::translate("GLOBAL","ManualColorChange:")+QString::number(FUN_PUNCHMANUALCHANGECOLOR)+";"+//手动换色
                                    QCoreApplication::translate("GLOBAL","ForwardOrBackward:")+QString::number(FUN_FORWARDORBACK)+";"+//前进回退
                                    QCoreApplication::translate("GLOBAL","ProcessReset:")+QString::number(FUN_PROCESSRESET)+";"+//流程复位
                                    QCoreApplication::translate("GLOBAL","SinglePunch:")+QString::number(FUN_SINGLEPUNCH)+";"+//单次冲孔
                                    QCoreApplication::translate("GLOBAL","FrameZero:")+QString::number(FUN_FRAMEZERO)+";"+//框架归零
                                    QCoreApplication::translate("GLOBAL","MoveToRightUp:")+QString::number(FUN_MOVETORIGHTUP)+";"+//去右上角
                                    QCoreApplication::translate("GLOBAL","MoveToRightDown:")+QString::number(FUN_MOVETORIGHTDOWN)+";"+//去右下角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftUp:")+QString::number(FUN_MOVETOLEFTUP)+";"+//去左上角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftDown:")+QString::number(FUN_MOVETOLEFTDOWN)+";"+//去左下角
                                    QCoreApplication::translate("GLOBAL","SetWorkRange:")+QString::number(FUN_SETWORKRANGE)+";"+//定工作范围
                                    QCoreApplication::translate("GLOBAL","PunchStopLower:")+QString::number(FUN_PUNCHSTOPLOWER)+";"+//冲头停下位
                                    QCoreApplication::translate("GLOBAL","PatternSelect:")+QString::number(FUN_PATTERNSELECT)+";"+//花样选择
                                    QCoreApplication::translate("GLOBAL","DrawOutline:")+QString::number(FUN_DRAWOUTLINE)+";"+//画轮廓线 xcy20220909
                                    QCoreApplication::translate("GLOBAL","ToolDebug:")+QString::number(FUN_ROTATECOMPENSATE)+";"+//旋转补偿
                                    QCoreApplication::translate("GLOBAL","Null:")+QString::number(FUN_NULL)+";"),//无功能
                                   FUN_DRAWOUTLINE, FUN_DRAWOUTLINE, 0x000A, operate));
    //常用功能设置参数---------------------------
}

//冲缝机常用功能设置参数
void initPunchSewCommonFunParasList(QList<ParaItem> &parasList)
{
    //常用功能设置参数---------------------------
    //常用功能设置参数-常用按钮1；单位：无 ，范围全部，默认
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_COMMONFUN,
                                   0 ,
                                   1, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Frequently used button1"),//常用按钮1
                                   FUN_PATTERNSELECT, FUN_ALLTOZERO, FUN_NULL, FUN_PATTERNSELECT, 0, "", "",
                                   (QCoreApplication::translate("GLOBAL", "AllToZero:")+QString::number(FUN_ALLTOZERO)+";"+//全部归零
                                    QCoreApplication::translate("GLOBAL","SpindleTest:")+QString::number(FUN_SPINDLETEST)+";"+//冲孔主轴研车
                                    QCoreApplication::translate("GLOBAL","SetOffsetPoint:")+QString::number(FUN_SETOFFSETPOINT)+";"+//定偏移点
                                    QCoreApplication::translate("GLOBAL","BackOffsetPoint:")+QString::number(FUN_BACKOFFSETPOINT)+";"+//回偏移点
                                    QCoreApplication::translate("GLOBAL","SetStartPoint:")+QString::number(FUN_SETSTARTPOINT)+";"+//定起始点
                                    QCoreApplication::translate("GLOBAL","BackStartPoint:")+QString::number(FUN_BACKSTARTPOINT)+";"+//回起始点
                                    QCoreApplication::translate("GLOBAL","BackWorkPoint:")+QString::number(FUN_BACKWORKPOINT)+";"+//回工作点
                                    QCoreApplication::translate("GLOBAL","CheckFrame:")+QString::number(FUN_CHECKFRAME)+";"+//边框检查
                                    QCoreApplication::translate("GLOBAL","ForwardOrBackward:")+QString::number(FUN_FORWARDORBACK)+";"+//前进回退
                                    QCoreApplication::translate("GLOBAL","PunchSpindleJog:")+QString::number(FUN_PUNCHSPINDLEJOG)+";"+//冲孔主轴点动
                                    QCoreApplication::translate("GLOBAL","ManualColorChange:")+QString::number(FUN_PUNCHMANUALCHANGECOLOR)+";"+//手动换色
                                    QCoreApplication::translate("GLOBAL","SinglePunch:")+QString::number(FUN_SINGLEPUNCH)+";"+//单次冲孔
                                    QCoreApplication::translate("GLOBAL","FrameZero:")+QString::number(FUN_FRAMEZERO)+";"+//框架归零
                                    QCoreApplication::translate("GLOBAL","MoveToRightUp:")+QString::number(FUN_MOVETORIGHTUP)+";"+//去右上角
                                    QCoreApplication::translate("GLOBAL","MoveToRightDown:")+QString::number(FUN_MOVETORIGHTDOWN)+";"+//去右下角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftUp:")+QString::number(FUN_MOVETOLEFTUP)+";"+//去左上角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftDown:")+QString::number(FUN_MOVETOLEFTDOWN)+";"+//去左下角
                                    QCoreApplication::translate("GLOBAL","SetWorkRange:")+QString::number(FUN_SETWORKRANGE)+";"+//定工作范围
                                    QCoreApplication::translate("GLOBAL","PatternSelect:")+QString::number(FUN_PATTERNSELECT)+";"+//花样选择
                                    QCoreApplication::translate("GLOBAL","PunchStopLower:")+QString::number(FUN_PUNCHSTOPLOWER)+";"+//冲头停下位
                                    QCoreApplication::translate("GLOBAL","SewSpindleTest:")+QString::number(FUN_SEWSPINDLETEST)+";"+//缝纫主轴研车
                                    QCoreApplication::translate("GLOBAL","Sewing head lifting:")+QString::number(FUN_SEWMOTORUPDOWN)+";"+//缝纫机头升降
                                    QCoreApplication::translate("GLOBAL","SewSpindleJog:")+QString::number(FUN_SEWSPINDLEJOG)+";"+//缝纫主轴点动
                                    QCoreApplication::translate("GLOBAL","PunchSetStartPoint:")+QString::number(FUN_SECSETSTARTPOINT)+";"+//冲孔定起始点（第二机头定起始点）
                                    QCoreApplication::translate("GLOBAL","ChangeMachineSewHead:")+QString::number(FUN_SELECTSEWHEAD)+";"+//切换缝纫机头
                                    QCoreApplication::translate("GLOBAL","ChangeMachinePunchHead:")+QString::number(FUN_SELECTPUCNHHEAD)+";"+//切换冲孔机头
                                    QCoreApplication::translate("GLOBAL","Head 1 thread trimming:")+QString::number(FUN_SEWHEADCUTLINEO)+";"+//机头1剪线
                                    QCoreApplication::translate("GLOBAL","Head 2 thread trimming:")+QString::number(FUN_SEWHEADCUTLINET)+";"+//机头2剪线
                                    QCoreApplication::translate("GLOBAL","Needle shuttle proofreading:")+QString::number(FUN_NEEDLECONTRAST)+";"+//针梭校对
                                    QCoreApplication::translate("GLOBAL","BackCenter:")+QString::number(FUN_RETURNTOCENTERPOINT)+";"+//回中心点
                                    QCoreApplication::translate("GLOBAL","Null:")+QString::number(FUN_NULL)+";"),//无功能
                                   FUN_PATTERNSELECT, FUN_PATTERNSELECT, 0x0001, operate));

    //常用功能设置参数-常用按钮2；单位：无 ，范围全部，默认
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_COMMONFUN,
                                   0 ,
                                   2, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Frequently used button2"),//常用按钮2
                                   FUN_SETSTARTPOINT, FUN_ALLTOZERO, FUN_NULL, FUN_SETSTARTPOINT, 0, "", "",
                                   (QCoreApplication::translate("GLOBAL", "AllToZero:")+QString::number(FUN_ALLTOZERO)+";"+//全部归零
                                    QCoreApplication::translate("GLOBAL","SpindleTest:")+QString::number(FUN_SPINDLETEST)+";"+//冲孔主轴研车
                                    QCoreApplication::translate("GLOBAL","SetOffsetPoint:")+QString::number(FUN_SETOFFSETPOINT)+";"+//定偏移点
                                    QCoreApplication::translate("GLOBAL","BackOffsetPoint:")+QString::number(FUN_BACKOFFSETPOINT)+";"+//回偏移点
                                    QCoreApplication::translate("GLOBAL","SetStartPoint:")+QString::number(FUN_SETSTARTPOINT)+";"+//定起始点
                                    QCoreApplication::translate("GLOBAL","BackStartPoint:")+QString::number(FUN_BACKSTARTPOINT)+";"+//回起始点
                                    QCoreApplication::translate("GLOBAL","BackWorkPoint:")+QString::number(FUN_BACKWORKPOINT)+";"+//回工作点
                                    QCoreApplication::translate("GLOBAL","CheckFrame:")+QString::number(FUN_CHECKFRAME)+";"+//边框检查
                                    QCoreApplication::translate("GLOBAL","ForwardOrBackward:")+QString::number(FUN_FORWARDORBACK)+";"+//前进回退
                                    QCoreApplication::translate("GLOBAL","PunchSpindleJog:")+QString::number(FUN_PUNCHSPINDLEJOG)+";"+//冲孔主轴点动
                                    QCoreApplication::translate("GLOBAL","ManualColorChange:")+QString::number(FUN_PUNCHMANUALCHANGECOLOR)+";"+//手动换色
                                    QCoreApplication::translate("GLOBAL","SinglePunch:")+QString::number(FUN_SINGLEPUNCH)+";"+//单次冲孔
                                    QCoreApplication::translate("GLOBAL","FrameZero:")+QString::number(FUN_FRAMEZERO)+";"+//框架归零
                                    QCoreApplication::translate("GLOBAL","MoveToRightUp:")+QString::number(FUN_MOVETORIGHTUP)+";"+//去右上角
                                    QCoreApplication::translate("GLOBAL","MoveToRightDown:")+QString::number(FUN_MOVETORIGHTDOWN)+";"+//去右下角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftUp:")+QString::number(FUN_MOVETOLEFTUP)+";"+//去左上角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftDown:")+QString::number(FUN_MOVETOLEFTDOWN)+";"+//去左下角
                                    QCoreApplication::translate("GLOBAL","SetWorkRange:")+QString::number(FUN_SETWORKRANGE)+";"+//定工作范围
                                    QCoreApplication::translate("GLOBAL","PatternSelect:")+QString::number(FUN_PATTERNSELECT)+";"+//花样选择
                                    QCoreApplication::translate("GLOBAL","PunchStopLower:")+QString::number(FUN_PUNCHSTOPLOWER)+";"+//冲头停下位
                                    QCoreApplication::translate("GLOBAL","SewSpindleTest:")+QString::number(FUN_SEWSPINDLETEST)+";"+//缝纫主轴研车
                                    QCoreApplication::translate("GLOBAL","Sewing head lifting:")+QString::number(FUN_SEWMOTORUPDOWN)+";"+//缝纫机头升降
                                    QCoreApplication::translate("GLOBAL","SewSpindleJog:")+QString::number(FUN_SEWSPINDLEJOG)+";"+//缝纫主轴点动
                                    QCoreApplication::translate("GLOBAL","PunchSetStartPoint:")+QString::number(FUN_SECSETSTARTPOINT)+";"+//冲孔定起始点（第二机头定起始点）
                                    QCoreApplication::translate("GLOBAL","ChangeMachineSewHead:")+QString::number(FUN_SELECTSEWHEAD)+";"+//切换缝纫机头
                                    QCoreApplication::translate("GLOBAL","ChangeMachinePunchHead:")+QString::number(FUN_SELECTPUCNHHEAD)+";"+//切换冲孔机头
                                    QCoreApplication::translate("GLOBAL","Head 1 thread trimming:")+QString::number(FUN_SEWHEADCUTLINEO)+";"+//机头1剪线
                                    QCoreApplication::translate("GLOBAL","Head 2 thread trimming:")+QString::number(FUN_SEWHEADCUTLINET)+";"+//机头2剪线
                                    QCoreApplication::translate("GLOBAL","Needle shuttle proofreading:")+QString::number(FUN_NEEDLECONTRAST)+";"+//针梭校对
                                    QCoreApplication::translate("GLOBAL","BackCenter:")+QString::number(FUN_RETURNTOCENTERPOINT)+";"+//回中心点
                                    QCoreApplication::translate("GLOBAL","Null:")+QString::number(FUN_NULL)+";"),//无功能
                                   FUN_SETSTARTPOINT, FUN_SETSTARTPOINT, 0x0002, operate));

    //常用功能设置参数-常用按钮3；单位：无 ，范围全部，默认
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_COMMONFUN,
                                   0 ,
                                   3, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Frequently used button3"),//常用按钮3
                                   FUN_BACKSTARTPOINT, FUN_ALLTOZERO, FUN_NULL, FUN_BACKSTARTPOINT, 0, "", "",
                                   (QCoreApplication::translate("GLOBAL", "AllToZero:")+QString::number(FUN_ALLTOZERO)+";"+//全部归零
                                    QCoreApplication::translate("GLOBAL","SpindleTest:")+QString::number(FUN_SPINDLETEST)+";"+//冲孔主轴研车
                                    QCoreApplication::translate("GLOBAL","SetOffsetPoint:")+QString::number(FUN_SETOFFSETPOINT)+";"+//定偏移点
                                    QCoreApplication::translate("GLOBAL","BackOffsetPoint:")+QString::number(FUN_BACKOFFSETPOINT)+";"+//回偏移点
                                    QCoreApplication::translate("GLOBAL","SetStartPoint:")+QString::number(FUN_SETSTARTPOINT)+";"+//定起始点
                                    QCoreApplication::translate("GLOBAL","BackStartPoint:")+QString::number(FUN_BACKSTARTPOINT)+";"+//回起始点
                                    QCoreApplication::translate("GLOBAL","BackWorkPoint:")+QString::number(FUN_BACKWORKPOINT)+";"+//回工作点
                                    QCoreApplication::translate("GLOBAL","CheckFrame:")+QString::number(FUN_CHECKFRAME)+";"+//边框检查
                                    QCoreApplication::translate("GLOBAL","ForwardOrBackward:")+QString::number(FUN_FORWARDORBACK)+";"+//前进回退
                                    QCoreApplication::translate("GLOBAL","PunchSpindleJog:")+QString::number(FUN_PUNCHSPINDLEJOG)+";"+//冲孔主轴点动
                                    QCoreApplication::translate("GLOBAL","ManualColorChange:")+QString::number(FUN_PUNCHMANUALCHANGECOLOR)+";"+//手动换色
                                    QCoreApplication::translate("GLOBAL","SinglePunch:")+QString::number(FUN_SINGLEPUNCH)+";"+//单次冲孔
                                    QCoreApplication::translate("GLOBAL","FrameZero:")+QString::number(FUN_FRAMEZERO)+";"+//框架归零
                                    QCoreApplication::translate("GLOBAL","MoveToRightUp:")+QString::number(FUN_MOVETORIGHTUP)+";"+//去右上角
                                    QCoreApplication::translate("GLOBAL","MoveToRightDown:")+QString::number(FUN_MOVETORIGHTDOWN)+";"+//去右下角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftUp:")+QString::number(FUN_MOVETOLEFTUP)+";"+//去左上角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftDown:")+QString::number(FUN_MOVETOLEFTDOWN)+";"+//去左下角
                                    QCoreApplication::translate("GLOBAL","SetWorkRange:")+QString::number(FUN_SETWORKRANGE)+";"+//定工作范围
                                    QCoreApplication::translate("GLOBAL","PatternSelect:")+QString::number(FUN_PATTERNSELECT)+";"+//花样选择
                                    QCoreApplication::translate("GLOBAL","PunchStopLower:")+QString::number(FUN_PUNCHSTOPLOWER)+";"+//冲头停下位
                                    QCoreApplication::translate("GLOBAL","SewSpindleTest:")+QString::number(FUN_SEWSPINDLETEST)+";"+//缝纫主轴研车
                                    QCoreApplication::translate("GLOBAL","Sewing head lifting:")+QString::number(FUN_SEWMOTORUPDOWN)+";"+//缝纫机头升降
                                    QCoreApplication::translate("GLOBAL","SewSpindleJog:")+QString::number(FUN_SEWSPINDLEJOG)+";"+//缝纫主轴点动
                                    QCoreApplication::translate("GLOBAL","PunchSetStartPoint:")+QString::number(FUN_SECSETSTARTPOINT)+";"+//冲孔定起始点（第二机头定起始点）
                                    QCoreApplication::translate("GLOBAL","ChangeMachineSewHead:")+QString::number(FUN_SELECTSEWHEAD)+";"+//切换缝纫机头
                                    QCoreApplication::translate("GLOBAL","ChangeMachinePunchHead:")+QString::number(FUN_SELECTPUCNHHEAD)+";"+//切换冲孔机头
                                    QCoreApplication::translate("GLOBAL","Head 1 thread trimming:")+QString::number(FUN_SEWHEADCUTLINEO)+";"+//机头1剪线
                                    QCoreApplication::translate("GLOBAL","Head 2 thread trimming:")+QString::number(FUN_SEWHEADCUTLINET)+";"+//机头2剪线
                                    QCoreApplication::translate("GLOBAL","Needle shuttle proofreading:")+QString::number(FUN_NEEDLECONTRAST)+";"+//针梭校对
                                    QCoreApplication::translate("GLOBAL","BackCenter:")+QString::number(FUN_RETURNTOCENTERPOINT)+";"+//回中心点
                                    QCoreApplication::translate("GLOBAL","Null:")+QString::number(FUN_NULL)+";"),//无功能
                                   FUN_BACKSTARTPOINT, FUN_BACKSTARTPOINT, 0x0003, operate));

    //常用功能设置参数-常用按钮4；单位：无 ，范围全部，默认FUN_BACKOFFSETPOINT
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_COMMONFUN,
                                   0 ,
                                   4, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Frequently used button4"),//常用按钮4
                                   FUN_CHECKFRAME, FUN_ALLTOZERO, FUN_NULL, FUN_CHECKFRAME, 0, "", "",
                                   (QCoreApplication::translate("GLOBAL", "AllToZero:")+QString::number(FUN_ALLTOZERO)+";"+//全部归零
                                    QCoreApplication::translate("GLOBAL","SpindleTest:")+QString::number(FUN_SPINDLETEST)+";"+//冲孔主轴研车
                                    QCoreApplication::translate("GLOBAL","SetOffsetPoint:")+QString::number(FUN_SETOFFSETPOINT)+";"+//定偏移点
                                    QCoreApplication::translate("GLOBAL","BackOffsetPoint:")+QString::number(FUN_BACKOFFSETPOINT)+";"+//回偏移点
                                    QCoreApplication::translate("GLOBAL","SetStartPoint:")+QString::number(FUN_SETSTARTPOINT)+";"+//定起始点
                                    QCoreApplication::translate("GLOBAL","BackStartPoint:")+QString::number(FUN_BACKSTARTPOINT)+";"+//回起始点
                                    QCoreApplication::translate("GLOBAL","BackWorkPoint:")+QString::number(FUN_BACKWORKPOINT)+";"+//回工作点
                                    QCoreApplication::translate("GLOBAL","CheckFrame:")+QString::number(FUN_CHECKFRAME)+";"+//边框检查
                                    QCoreApplication::translate("GLOBAL","ForwardOrBackward:")+QString::number(FUN_FORWARDORBACK)+";"+//前进回退
                                    QCoreApplication::translate("GLOBAL","PunchSpindleJog:")+QString::number(FUN_PUNCHSPINDLEJOG)+";"+//冲孔主轴点动
                                    QCoreApplication::translate("GLOBAL","ManualColorChange:")+QString::number(FUN_PUNCHMANUALCHANGECOLOR)+";"+//手动换色
                                    QCoreApplication::translate("GLOBAL","SinglePunch:")+QString::number(FUN_SINGLEPUNCH)+";"+//单次冲孔
                                    QCoreApplication::translate("GLOBAL","FrameZero:")+QString::number(FUN_FRAMEZERO)+";"+//框架归零
                                    QCoreApplication::translate("GLOBAL","MoveToRightUp:")+QString::number(FUN_MOVETORIGHTUP)+";"+//去右上角
                                    QCoreApplication::translate("GLOBAL","MoveToRightDown:")+QString::number(FUN_MOVETORIGHTDOWN)+";"+//去右下角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftUp:")+QString::number(FUN_MOVETOLEFTUP)+";"+//去左上角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftDown:")+QString::number(FUN_MOVETOLEFTDOWN)+";"+//去左下角
                                    QCoreApplication::translate("GLOBAL","SetWorkRange:")+QString::number(FUN_SETWORKRANGE)+";"+//定工作范围
                                    QCoreApplication::translate("GLOBAL","PatternSelect:")+QString::number(FUN_PATTERNSELECT)+";"+//花样选择
                                    QCoreApplication::translate("GLOBAL","PunchStopLower:")+QString::number(FUN_PUNCHSTOPLOWER)+";"+//冲头停下位
                                    QCoreApplication::translate("GLOBAL","SewSpindleTest:")+QString::number(FUN_SEWSPINDLETEST)+";"+//缝纫主轴研车
                                    QCoreApplication::translate("GLOBAL","Sewing head lifting:")+QString::number(FUN_SEWMOTORUPDOWN)+";"+//缝纫机头升降
                                    QCoreApplication::translate("GLOBAL","SewSpindleJog:")+QString::number(FUN_SEWSPINDLEJOG)+";"+//缝纫主轴点动
                                    QCoreApplication::translate("GLOBAL","PunchSetStartPoint:")+QString::number(FUN_SECSETSTARTPOINT)+";"+//冲孔定起始点（第二机头定起始点）
                                    QCoreApplication::translate("GLOBAL","ChangeMachineSewHead:")+QString::number(FUN_SELECTSEWHEAD)+";"+//切换缝纫机头
                                    QCoreApplication::translate("GLOBAL","ChangeMachinePunchHead:")+QString::number(FUN_SELECTPUCNHHEAD)+";"+//切换冲孔机头
                                    QCoreApplication::translate("GLOBAL","Head 1 thread trimming:")+QString::number(FUN_SEWHEADCUTLINEO)+";"+//机头1剪线
                                    QCoreApplication::translate("GLOBAL","Head 2 thread trimming:")+QString::number(FUN_SEWHEADCUTLINET)+";"+//机头2剪线
                                    QCoreApplication::translate("GLOBAL","Needle shuttle proofreading:")+QString::number(FUN_NEEDLECONTRAST)+";"+//针梭校对
                                    QCoreApplication::translate("GLOBAL","BackCenter:")+QString::number(FUN_RETURNTOCENTERPOINT)+";"+//回中心点
                                    QCoreApplication::translate("GLOBAL","Null:")+QString::number(FUN_NULL)+";"),//无功能
                                   FUN_CHECKFRAME, FUN_CHECKFRAME, 0x0004, operate));

    //常用功能设置参数-常用按钮5；单位：无 ，范围全部，默认
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_COMMONFUN,
                                   0 ,
                                   5, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Frequently used button5"),//常用按钮5
                                   FUN_BACKWORKPOINT, FUN_ALLTOZERO, FUN_NULL, FUN_BACKWORKPOINT, 0, "", "",
                                   (QCoreApplication::translate("GLOBAL", "AllToZero:")+QString::number(FUN_ALLTOZERO)+";"+//全部归零
                                    QCoreApplication::translate("GLOBAL","SpindleTest:")+QString::number(FUN_SPINDLETEST)+";"+//冲孔主轴研车
                                    QCoreApplication::translate("GLOBAL","SetOffsetPoint:")+QString::number(FUN_SETOFFSETPOINT)+";"+//定偏移点
                                    QCoreApplication::translate("GLOBAL","BackOffsetPoint:")+QString::number(FUN_BACKOFFSETPOINT)+";"+//回偏移点
                                    QCoreApplication::translate("GLOBAL","SetStartPoint:")+QString::number(FUN_SETSTARTPOINT)+";"+//定起始点
                                    QCoreApplication::translate("GLOBAL","BackStartPoint:")+QString::number(FUN_BACKSTARTPOINT)+";"+//回起始点
                                    QCoreApplication::translate("GLOBAL","BackWorkPoint:")+QString::number(FUN_BACKWORKPOINT)+";"+//回工作点
                                    QCoreApplication::translate("GLOBAL","CheckFrame:")+QString::number(FUN_CHECKFRAME)+";"+//边框检查
                                    QCoreApplication::translate("GLOBAL","ForwardOrBackward:")+QString::number(FUN_FORWARDORBACK)+";"+//前进回退
                                    QCoreApplication::translate("GLOBAL","PunchSpindleJog:")+QString::number(FUN_PUNCHSPINDLEJOG)+";"+//冲孔主轴点动
                                    QCoreApplication::translate("GLOBAL","ManualColorChange:")+QString::number(FUN_PUNCHMANUALCHANGECOLOR)+";"+//手动换色
                                    QCoreApplication::translate("GLOBAL","SinglePunch:")+QString::number(FUN_SINGLEPUNCH)+";"+//单次冲孔
                                    QCoreApplication::translate("GLOBAL","FrameZero:")+QString::number(FUN_FRAMEZERO)+";"+//框架归零
                                    QCoreApplication::translate("GLOBAL","MoveToRightUp:")+QString::number(FUN_MOVETORIGHTUP)+";"+//去右上角
                                    QCoreApplication::translate("GLOBAL","MoveToRightDown:")+QString::number(FUN_MOVETORIGHTDOWN)+";"+//去右下角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftUp:")+QString::number(FUN_MOVETOLEFTUP)+";"+//去左上角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftDown:")+QString::number(FUN_MOVETOLEFTDOWN)+";"+//去左下角
                                    QCoreApplication::translate("GLOBAL","SetWorkRange:")+QString::number(FUN_SETWORKRANGE)+";"+//定工作范围
                                    QCoreApplication::translate("GLOBAL","PatternSelect:")+QString::number(FUN_PATTERNSELECT)+";"+//花样选择
                                    QCoreApplication::translate("GLOBAL","PunchStopLower:")+QString::number(FUN_PUNCHSTOPLOWER)+";"+//冲头停下位
                                    QCoreApplication::translate("GLOBAL","SewSpindleTest:")+QString::number(FUN_SEWSPINDLETEST)+";"+//缝纫主轴研车
                                    QCoreApplication::translate("GLOBAL","Sewing head lifting:")+QString::number(FUN_SEWMOTORUPDOWN)+";"+//缝纫机头升降
                                    QCoreApplication::translate("GLOBAL","SewSpindleJog:")+QString::number(FUN_SEWSPINDLEJOG)+";"+//缝纫主轴点动
                                    QCoreApplication::translate("GLOBAL","PunchSetStartPoint:")+QString::number(FUN_SECSETSTARTPOINT)+";"+//冲孔定起始点（第二机头定起始点）
                                    QCoreApplication::translate("GLOBAL","ChangeMachineSewHead:")+QString::number(FUN_SELECTSEWHEAD)+";"+//切换缝纫机头
                                    QCoreApplication::translate("GLOBAL","ChangeMachinePunchHead:")+QString::number(FUN_SELECTPUCNHHEAD)+";"+//切换冲孔机头
                                    QCoreApplication::translate("GLOBAL","Head 1 thread trimming:")+QString::number(FUN_SEWHEADCUTLINEO)+";"+//机头1剪线
                                    QCoreApplication::translate("GLOBAL","Head 2 thread trimming:")+QString::number(FUN_SEWHEADCUTLINET)+";"+//机头2剪线
                                    QCoreApplication::translate("GLOBAL","Needle shuttle proofreading:")+QString::number(FUN_NEEDLECONTRAST)+";"+//针梭校对
                                    QCoreApplication::translate("GLOBAL","BackCenter:")+QString::number(FUN_RETURNTOCENTERPOINT)+";"+//回中心点
                                    QCoreApplication::translate("GLOBAL","Null:")+QString::number(FUN_NULL)+";"),//无功能
                                   FUN_BACKWORKPOINT, FUN_BACKWORKPOINT, 0x0005, operate));

    //常用功能设置参数-常用按钮6；单位：无 ，范围全部，默认
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_COMMONFUN,
                                   0 ,
                                   6, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Frequently used button6"),//常用按钮6
                                   FUN_SETOFFSETPOINT, FUN_ALLTOZERO, FUN_NULL, FUN_SETOFFSETPOINT, 0, "", "",
                                   (QCoreApplication::translate("GLOBAL", "AllToZero:")+QString::number(FUN_ALLTOZERO)+";"+//全部归零
                                    QCoreApplication::translate("GLOBAL","SpindleTest:")+QString::number(FUN_SPINDLETEST)+";"+//冲孔主轴研车
                                    QCoreApplication::translate("GLOBAL","SetOffsetPoint:")+QString::number(FUN_SETOFFSETPOINT)+";"+//定偏移点
                                    QCoreApplication::translate("GLOBAL","BackOffsetPoint:")+QString::number(FUN_BACKOFFSETPOINT)+";"+//回偏移点
                                    QCoreApplication::translate("GLOBAL","SetStartPoint:")+QString::number(FUN_SETSTARTPOINT)+";"+//定起始点
                                    QCoreApplication::translate("GLOBAL","BackStartPoint:")+QString::number(FUN_BACKSTARTPOINT)+";"+//回起始点
                                    QCoreApplication::translate("GLOBAL","BackWorkPoint:")+QString::number(FUN_BACKWORKPOINT)+";"+//回工作点
                                    QCoreApplication::translate("GLOBAL","CheckFrame:")+QString::number(FUN_CHECKFRAME)+";"+//边框检查
                                    QCoreApplication::translate("GLOBAL","ForwardOrBackward:")+QString::number(FUN_FORWARDORBACK)+";"+//前进回退
                                    QCoreApplication::translate("GLOBAL","PunchSpindleJog:")+QString::number(FUN_PUNCHSPINDLEJOG)+";"+//冲孔主轴点动
                                    QCoreApplication::translate("GLOBAL","ManualColorChange:")+QString::number(FUN_PUNCHMANUALCHANGECOLOR)+";"+//手动换色
                                    QCoreApplication::translate("GLOBAL","SinglePunch:")+QString::number(FUN_SINGLEPUNCH)+";"+//单次冲孔
                                    QCoreApplication::translate("GLOBAL","FrameZero:")+QString::number(FUN_FRAMEZERO)+";"+//框架归零
                                    QCoreApplication::translate("GLOBAL","MoveToRightUp:")+QString::number(FUN_MOVETORIGHTUP)+";"+//去右上角
                                    QCoreApplication::translate("GLOBAL","MoveToRightDown:")+QString::number(FUN_MOVETORIGHTDOWN)+";"+//去右下角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftUp:")+QString::number(FUN_MOVETOLEFTUP)+";"+//去左上角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftDown:")+QString::number(FUN_MOVETOLEFTDOWN)+";"+//去左下角
                                    QCoreApplication::translate("GLOBAL","SetWorkRange:")+QString::number(FUN_SETWORKRANGE)+";"+//定工作范围
                                    QCoreApplication::translate("GLOBAL","PatternSelect:")+QString::number(FUN_PATTERNSELECT)+";"+//花样选择
                                    QCoreApplication::translate("GLOBAL","PunchStopLower:")+QString::number(FUN_PUNCHSTOPLOWER)+";"+//冲头停下位
                                    QCoreApplication::translate("GLOBAL","SewSpindleTest:")+QString::number(FUN_SEWSPINDLETEST)+";"+//缝纫主轴研车
                                    QCoreApplication::translate("GLOBAL","Sewing head lifting:")+QString::number(FUN_SEWMOTORUPDOWN)+";"+//缝纫机头升降
                                    QCoreApplication::translate("GLOBAL","SewSpindleJog:")+QString::number(FUN_SEWSPINDLEJOG)+";"+//缝纫主轴点动
                                    QCoreApplication::translate("GLOBAL","PunchSetStartPoint:")+QString::number(FUN_SECSETSTARTPOINT)+";"+//冲孔定起始点（第二机头定起始点）
                                    QCoreApplication::translate("GLOBAL","ChangeMachineSewHead:")+QString::number(FUN_SELECTSEWHEAD)+";"+//切换缝纫机头
                                    QCoreApplication::translate("GLOBAL","ChangeMachinePunchHead:")+QString::number(FUN_SELECTPUCNHHEAD)+";"+//切换冲孔机头
                                    QCoreApplication::translate("GLOBAL","Head 1 thread trimming:")+QString::number(FUN_SEWHEADCUTLINEO)+";"+//机头1剪线
                                    QCoreApplication::translate("GLOBAL","Head 2 thread trimming:")+QString::number(FUN_SEWHEADCUTLINET)+";"+//机头2剪线
                                    QCoreApplication::translate("GLOBAL","Needle shuttle proofreading:")+QString::number(FUN_NEEDLECONTRAST)+";"+//针梭校对
                                    QCoreApplication::translate("GLOBAL","BackCenter:")+QString::number(FUN_RETURNTOCENTERPOINT)+";"+//回中心点
                                    QCoreApplication::translate("GLOBAL","Null:")+QString::number(FUN_NULL)+";"),//无功能
                                   FUN_SETOFFSETPOINT, FUN_SETOFFSETPOINT, 0x0006, operate));

    //常用功能设置参数-常用按钮7；单位：无 ，范围全部，默认
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_COMMONFUN,
                                   0 ,
                                   7, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Frequently used button7"),//常用按钮7
                                   FUN_BACKOFFSETPOINT, FUN_ALLTOZERO, FUN_NULL, FUN_BACKOFFSETPOINT, 0, "", "",
                                   (QCoreApplication::translate("GLOBAL", "AllToZero:")+QString::number(FUN_ALLTOZERO)+";"+//全部归零
                                    QCoreApplication::translate("GLOBAL","SpindleTest:")+QString::number(FUN_SPINDLETEST)+";"+//冲孔主轴研车
                                    QCoreApplication::translate("GLOBAL","SetOffsetPoint:")+QString::number(FUN_SETOFFSETPOINT)+";"+//定偏移点
                                    QCoreApplication::translate("GLOBAL","BackOffsetPoint:")+QString::number(FUN_BACKOFFSETPOINT)+";"+//回偏移点
                                    QCoreApplication::translate("GLOBAL","SetStartPoint:")+QString::number(FUN_SETSTARTPOINT)+";"+//定起始点
                                    QCoreApplication::translate("GLOBAL","BackStartPoint:")+QString::number(FUN_BACKSTARTPOINT)+";"+//回起始点
                                    QCoreApplication::translate("GLOBAL","BackWorkPoint:")+QString::number(FUN_BACKWORKPOINT)+";"+//回工作点
                                    QCoreApplication::translate("GLOBAL","CheckFrame:")+QString::number(FUN_CHECKFRAME)+";"+//边框检查
                                    QCoreApplication::translate("GLOBAL","ForwardOrBackward:")+QString::number(FUN_FORWARDORBACK)+";"+//前进回退
                                    QCoreApplication::translate("GLOBAL","PunchSpindleJog:")+QString::number(FUN_PUNCHSPINDLEJOG)+";"+//冲孔主轴点动
                                    QCoreApplication::translate("GLOBAL","ManualColorChange:")+QString::number(FUN_PUNCHMANUALCHANGECOLOR)+";"+//手动换色
                                    QCoreApplication::translate("GLOBAL","SinglePunch:")+QString::number(FUN_SINGLEPUNCH)+";"+//单次冲孔
                                    QCoreApplication::translate("GLOBAL","FrameZero:")+QString::number(FUN_FRAMEZERO)+";"+//框架归零
                                    QCoreApplication::translate("GLOBAL","MoveToRightUp:")+QString::number(FUN_MOVETORIGHTUP)+";"+//去右上角
                                    QCoreApplication::translate("GLOBAL","MoveToRightDown:")+QString::number(FUN_MOVETORIGHTDOWN)+";"+//去右下角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftUp:")+QString::number(FUN_MOVETOLEFTUP)+";"+//去左上角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftDown:")+QString::number(FUN_MOVETOLEFTDOWN)+";"+//去左下角
                                    QCoreApplication::translate("GLOBAL","SetWorkRange:")+QString::number(FUN_SETWORKRANGE)+";"+//定工作范围
                                    QCoreApplication::translate("GLOBAL","PatternSelect:")+QString::number(FUN_PATTERNSELECT)+";"+//花样选择
                                    QCoreApplication::translate("GLOBAL","PunchStopLower:")+QString::number(FUN_PUNCHSTOPLOWER)+";"+//冲头停下位
                                    QCoreApplication::translate("GLOBAL","SewSpindleTest:")+QString::number(FUN_SEWSPINDLETEST)+";"+//缝纫主轴研车
                                    QCoreApplication::translate("GLOBAL","Sewing head lifting:")+QString::number(FUN_SEWMOTORUPDOWN)+";"+//缝纫机头升降
                                    QCoreApplication::translate("GLOBAL","SewSpindleJog:")+QString::number(FUN_SEWSPINDLEJOG)+";"+//缝纫主轴点动
                                    QCoreApplication::translate("GLOBAL","PunchSetStartPoint:")+QString::number(FUN_SECSETSTARTPOINT)+";"+//冲孔定起始点（第二机头定起始点）
                                    QCoreApplication::translate("GLOBAL","ChangeMachineSewHead:")+QString::number(FUN_SELECTSEWHEAD)+";"+//切换缝纫机头
                                    QCoreApplication::translate("GLOBAL","ChangeMachinePunchHead:")+QString::number(FUN_SELECTPUCNHHEAD)+";"+//切换冲孔机头
                                    QCoreApplication::translate("GLOBAL","Head 1 thread trimming:")+QString::number(FUN_SEWHEADCUTLINEO)+";"+//机头1剪线
                                    QCoreApplication::translate("GLOBAL","Head 2 thread trimming:")+QString::number(FUN_SEWHEADCUTLINET)+";"+//机头2剪线
                                    QCoreApplication::translate("GLOBAL","Needle shuttle proofreading:")+QString::number(FUN_NEEDLECONTRAST)+";"+//针梭校对
                                    QCoreApplication::translate("GLOBAL","BackCenter:")+QString::number(FUN_RETURNTOCENTERPOINT)+";"+//回中心点
                                    QCoreApplication::translate("GLOBAL","Null:")+QString::number(FUN_NULL)+";"),//无功能
                                   FUN_BACKOFFSETPOINT, FUN_BACKOFFSETPOINT, 0x0007, operate));

    //常用功能设置参数-常用按钮8；单位：无 ，范围全部，默认
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_COMMONFUN,
                                   0 ,
                                   8, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Frequently used button8"),//常用按钮8
                                   FUN_PUNCHSPINDLEJOG, FUN_ALLTOZERO, FUN_NULL, FUN_PUNCHSPINDLEJOG, 0, "", "",
                                   (QCoreApplication::translate("GLOBAL", "AllToZero:")+QString::number(FUN_ALLTOZERO)+";"+//全部归零
                                    QCoreApplication::translate("GLOBAL","SpindleTest:")+QString::number(FUN_SPINDLETEST)+";"+//冲孔主轴研车
                                    QCoreApplication::translate("GLOBAL","SetOffsetPoint:")+QString::number(FUN_SETOFFSETPOINT)+";"+//定偏移点
                                    QCoreApplication::translate("GLOBAL","BackOffsetPoint:")+QString::number(FUN_BACKOFFSETPOINT)+";"+//回偏移点
                                    QCoreApplication::translate("GLOBAL","SetStartPoint:")+QString::number(FUN_SETSTARTPOINT)+";"+//定起始点
                                    QCoreApplication::translate("GLOBAL","BackStartPoint:")+QString::number(FUN_BACKSTARTPOINT)+";"+//回起始点
                                    QCoreApplication::translate("GLOBAL","BackWorkPoint:")+QString::number(FUN_BACKWORKPOINT)+";"+//回工作点
                                    QCoreApplication::translate("GLOBAL","CheckFrame:")+QString::number(FUN_CHECKFRAME)+";"+//边框检查
                                    QCoreApplication::translate("GLOBAL","ForwardOrBackward:")+QString::number(FUN_FORWARDORBACK)+";"+//前进回退
                                    QCoreApplication::translate("GLOBAL","PunchSpindleJog:")+QString::number(FUN_PUNCHSPINDLEJOG)+";"+//冲孔主轴点动
                                    QCoreApplication::translate("GLOBAL","ManualColorChange:")+QString::number(FUN_PUNCHMANUALCHANGECOLOR)+";"+//手动换色
                                    QCoreApplication::translate("GLOBAL","SinglePunch:")+QString::number(FUN_SINGLEPUNCH)+";"+//单次冲孔
                                    QCoreApplication::translate("GLOBAL","FrameZero:")+QString::number(FUN_FRAMEZERO)+";"+//框架归零
                                    QCoreApplication::translate("GLOBAL","MoveToRightUp:")+QString::number(FUN_MOVETORIGHTUP)+";"+//去右上角
                                    QCoreApplication::translate("GLOBAL","MoveToRightDown:")+QString::number(FUN_MOVETORIGHTDOWN)+";"+//去右下角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftUp:")+QString::number(FUN_MOVETOLEFTUP)+";"+//去左上角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftDown:")+QString::number(FUN_MOVETOLEFTDOWN)+";"+//去左下角
                                    QCoreApplication::translate("GLOBAL","SetWorkRange:")+QString::number(FUN_SETWORKRANGE)+";"+//定工作范围
                                    QCoreApplication::translate("GLOBAL","PatternSelect:")+QString::number(FUN_PATTERNSELECT)+";"+//花样选择
                                    QCoreApplication::translate("GLOBAL","PunchStopLower:")+QString::number(FUN_PUNCHSTOPLOWER)+";"+//冲头停下位
                                    QCoreApplication::translate("GLOBAL","SewSpindleTest:")+QString::number(FUN_SEWSPINDLETEST)+";"+//缝纫主轴研车
                                    QCoreApplication::translate("GLOBAL","Sewing head lifting:")+QString::number(FUN_SEWMOTORUPDOWN)+";"+//缝纫机头升降
                                    QCoreApplication::translate("GLOBAL","SewSpindleJog:")+QString::number(FUN_SEWSPINDLEJOG)+";"+//缝纫主轴点动
                                    QCoreApplication::translate("GLOBAL","PunchSetStartPoint:")+QString::number(FUN_SECSETSTARTPOINT)+";"+//冲孔定起始点（第二机头定起始点）
                                    QCoreApplication::translate("GLOBAL","ChangeMachineSewHead:")+QString::number(FUN_SELECTSEWHEAD)+";"+//切换缝纫机头
                                    QCoreApplication::translate("GLOBAL","ChangeMachinePunchHead:")+QString::number(FUN_SELECTPUCNHHEAD)+";"+//切换冲孔机头
                                    QCoreApplication::translate("GLOBAL","Head 1 thread trimming:")+QString::number(FUN_SEWHEADCUTLINEO)+";"+//机头1剪线
                                    QCoreApplication::translate("GLOBAL","Head 2 thread trimming:")+QString::number(FUN_SEWHEADCUTLINET)+";"+//机头2剪线
                                    QCoreApplication::translate("GLOBAL","Needle shuttle proofreading:")+QString::number(FUN_NEEDLECONTRAST)+";"+//针梭校对
                                    QCoreApplication::translate("GLOBAL","BackCenter:")+QString::number(FUN_RETURNTOCENTERPOINT)+";"+//回中心点
                                    QCoreApplication::translate("GLOBAL","Null:")+QString::number(FUN_NULL)+";"),//无功能
                                   FUN_PUNCHSPINDLEJOG, FUN_PUNCHSPINDLEJOG, 0x0008, operate));

    //常用功能设置参数-常用按钮9；单位：无 ，范围全部，默认
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_COMMONFUN,
                                   0 ,
                                   9, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Frequently used button9"),//常用按钮9
                                   FUN_PUNCHMANUALCHANGECOLOR, FUN_ALLTOZERO, FUN_NULL, FUN_PUNCHMANUALCHANGECOLOR, 0, "", "",
                                   (QCoreApplication::translate("GLOBAL", "AllToZero:")+QString::number(FUN_ALLTOZERO)+";"+//全部归零
                                    QCoreApplication::translate("GLOBAL","SpindleTest:")+QString::number(FUN_SPINDLETEST)+";"+//冲孔主轴研车
                                    QCoreApplication::translate("GLOBAL","SetOffsetPoint:")+QString::number(FUN_SETOFFSETPOINT)+";"+//定偏移点
                                    QCoreApplication::translate("GLOBAL","BackOffsetPoint:")+QString::number(FUN_BACKOFFSETPOINT)+";"+//回偏移点
                                    QCoreApplication::translate("GLOBAL","SetStartPoint:")+QString::number(FUN_SETSTARTPOINT)+";"+//定起始点
                                    QCoreApplication::translate("GLOBAL","BackStartPoint:")+QString::number(FUN_BACKSTARTPOINT)+";"+//回起始点
                                    QCoreApplication::translate("GLOBAL","BackWorkPoint:")+QString::number(FUN_BACKWORKPOINT)+";"+//回工作点
                                    QCoreApplication::translate("GLOBAL","CheckFrame:")+QString::number(FUN_CHECKFRAME)+";"+//边框检查
                                    QCoreApplication::translate("GLOBAL","ForwardOrBackward:")+QString::number(FUN_FORWARDORBACK)+";"+//前进回退
                                    QCoreApplication::translate("GLOBAL","PunchSpindleJog:")+QString::number(FUN_PUNCHSPINDLEJOG)+";"+//冲孔主轴点动
                                    QCoreApplication::translate("GLOBAL","ManualColorChange:")+QString::number(FUN_PUNCHMANUALCHANGECOLOR)+";"+//手动换色
                                    QCoreApplication::translate("GLOBAL","SinglePunch:")+QString::number(FUN_SINGLEPUNCH)+";"+//单次冲孔
                                    QCoreApplication::translate("GLOBAL","FrameZero:")+QString::number(FUN_FRAMEZERO)+";"+//框架归零
                                    QCoreApplication::translate("GLOBAL","MoveToRightUp:")+QString::number(FUN_MOVETORIGHTUP)+";"+//去右上角
                                    QCoreApplication::translate("GLOBAL","MoveToRightDown:")+QString::number(FUN_MOVETORIGHTDOWN)+";"+//去右下角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftUp:")+QString::number(FUN_MOVETOLEFTUP)+";"+//去左上角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftDown:")+QString::number(FUN_MOVETOLEFTDOWN)+";"+//去左下角
                                    QCoreApplication::translate("GLOBAL","SetWorkRange:")+QString::number(FUN_SETWORKRANGE)+";"+//定工作范围
                                    QCoreApplication::translate("GLOBAL","PatternSelect:")+QString::number(FUN_PATTERNSELECT)+";"+//花样选择
                                    QCoreApplication::translate("GLOBAL","PunchStopLower:")+QString::number(FUN_PUNCHSTOPLOWER)+";"+//冲头停下位
                                    QCoreApplication::translate("GLOBAL","SewSpindleTest:")+QString::number(FUN_SEWSPINDLETEST)+";"+//缝纫主轴研车
                                    QCoreApplication::translate("GLOBAL","Sewing head lifting:")+QString::number(FUN_SEWMOTORUPDOWN)+";"+//缝纫机头升降
                                    QCoreApplication::translate("GLOBAL","SewSpindleJog:")+QString::number(FUN_SEWSPINDLEJOG)+";"+//缝纫主轴点动
                                    QCoreApplication::translate("GLOBAL","PunchSetStartPoint:")+QString::number(FUN_SECSETSTARTPOINT)+";"+//冲孔定起始点（第二机头定起始点）
                                    QCoreApplication::translate("GLOBAL","ChangeMachineSewHead:")+QString::number(FUN_SELECTSEWHEAD)+";"+//切换缝纫机头
                                    QCoreApplication::translate("GLOBAL","ChangeMachinePunchHead:")+QString::number(FUN_SELECTPUCNHHEAD)+";"+//切换冲孔机头
                                    QCoreApplication::translate("GLOBAL","Head 1 thread trimming:")+QString::number(FUN_SEWHEADCUTLINEO)+";"+//机头1剪线
                                    QCoreApplication::translate("GLOBAL","Head 2 thread trimming:")+QString::number(FUN_SEWHEADCUTLINET)+";"+//机头2剪线
                                    QCoreApplication::translate("GLOBAL","Needle shuttle proofreading:")+QString::number(FUN_NEEDLECONTRAST)+";"+//针梭校对
                                    QCoreApplication::translate("GLOBAL","BackCenter:")+QString::number(FUN_RETURNTOCENTERPOINT)+";"+//回中心点
                                    QCoreApplication::translate("GLOBAL","Null:")+QString::number(FUN_NULL)+";"),//无功能
                                   FUN_PUNCHMANUALCHANGECOLOR, FUN_PUNCHMANUALCHANGECOLOR, 0x0009, operate));

    //常用功能设置参数-常用按钮10；单位：无 ，范围全部，默认
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_COMMONFUN,
                                   0 ,
                                   10, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Frequently used button10"),//常用按钮10
                                   FUN_SINGLEPUNCH, FUN_ALLTOZERO, FUN_NULL, FUN_SINGLEPUNCH, 0, "", "",
                                   (QCoreApplication::translate("GLOBAL", "AllToZero:")+QString::number(FUN_ALLTOZERO)+";"+//全部归零
                                    QCoreApplication::translate("GLOBAL","SpindleTest:")+QString::number(FUN_SPINDLETEST)+";"+//冲孔主轴研车
                                    QCoreApplication::translate("GLOBAL","SetOffsetPoint:")+QString::number(FUN_SETOFFSETPOINT)+";"+//定偏移点
                                    QCoreApplication::translate("GLOBAL","BackOffsetPoint:")+QString::number(FUN_BACKOFFSETPOINT)+";"+//回偏移点
                                    QCoreApplication::translate("GLOBAL","SetStartPoint:")+QString::number(FUN_SETSTARTPOINT)+";"+//定起始点
                                    QCoreApplication::translate("GLOBAL","BackStartPoint:")+QString::number(FUN_BACKSTARTPOINT)+";"+//回起始点
                                    QCoreApplication::translate("GLOBAL","BackWorkPoint:")+QString::number(FUN_BACKWORKPOINT)+";"+//回工作点
                                    QCoreApplication::translate("GLOBAL","CheckFrame:")+QString::number(FUN_CHECKFRAME)+";"+//边框检查
                                    QCoreApplication::translate("GLOBAL","ForwardOrBackward:")+QString::number(FUN_FORWARDORBACK)+";"+//前进回退
                                    QCoreApplication::translate("GLOBAL","PunchSpindleJog:")+QString::number(FUN_PUNCHSPINDLEJOG)+";"+//冲孔主轴点动
                                    QCoreApplication::translate("GLOBAL","ManualColorChange:")+QString::number(FUN_PUNCHMANUALCHANGECOLOR)+";"+//手动换色
                                    QCoreApplication::translate("GLOBAL","SinglePunch:")+QString::number(FUN_SINGLEPUNCH)+";"+//单次冲孔
                                    QCoreApplication::translate("GLOBAL","FrameZero:")+QString::number(FUN_FRAMEZERO)+";"+//框架归零
                                    QCoreApplication::translate("GLOBAL","MoveToRightUp:")+QString::number(FUN_MOVETORIGHTUP)+";"+//去右上角
                                    QCoreApplication::translate("GLOBAL","MoveToRightDown:")+QString::number(FUN_MOVETORIGHTDOWN)+";"+//去右下角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftUp:")+QString::number(FUN_MOVETOLEFTUP)+";"+//去左上角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftDown:")+QString::number(FUN_MOVETOLEFTDOWN)+";"+//去左下角
                                    QCoreApplication::translate("GLOBAL","SetWorkRange:")+QString::number(FUN_SETWORKRANGE)+";"+//定工作范围
                                    QCoreApplication::translate("GLOBAL","PatternSelect:")+QString::number(FUN_PATTERNSELECT)+";"+//花样选择
                                    QCoreApplication::translate("GLOBAL","PunchStopLower:")+QString::number(FUN_PUNCHSTOPLOWER)+";"+//冲头停下位
                                    QCoreApplication::translate("GLOBAL","SewSpindleTest:")+QString::number(FUN_SEWSPINDLETEST)+";"+//缝纫主轴研车
                                    QCoreApplication::translate("GLOBAL","Sewing head lifting:")+QString::number(FUN_SEWMOTORUPDOWN)+";"+//缝纫机头升降
                                    QCoreApplication::translate("GLOBAL","SewSpindleJog:")+QString::number(FUN_SEWSPINDLEJOG)+";"+//缝纫主轴点动
                                    QCoreApplication::translate("GLOBAL","PunchSetStartPoint:")+QString::number(FUN_SECSETSTARTPOINT)+";"+//冲孔定起始点（第二机头定起始点）
                                    QCoreApplication::translate("GLOBAL","ChangeMachineSewHead:")+QString::number(FUN_SELECTSEWHEAD)+";"+//切换缝纫机头
                                    QCoreApplication::translate("GLOBAL","ChangeMachinePunchHead:")+QString::number(FUN_SELECTPUCNHHEAD)+";"+//切换冲孔机头
                                    QCoreApplication::translate("GLOBAL","Head 1 thread trimming:")+QString::number(FUN_SEWHEADCUTLINEO)+";"+//机头1剪线
                                    QCoreApplication::translate("GLOBAL","Head 2 thread trimming:")+QString::number(FUN_SEWHEADCUTLINET)+";"+//机头2剪线
                                    QCoreApplication::translate("GLOBAL","Needle shuttle proofreading:")+QString::number(FUN_NEEDLECONTRAST)+";"+//针梭校对
                                    QCoreApplication::translate("GLOBAL","BackCenter:")+QString::number(FUN_RETURNTOCENTERPOINT)+";"+//回中心点
                                    QCoreApplication::translate("GLOBAL","Null:")+QString::number(FUN_NULL)+";"),//无功能
                                   FUN_SINGLEPUNCH, FUN_SINGLEPUNCH, 0x000A, operate));
    //常用功能设置参数---------------------------
}
void initPunchEmbSewCommonFunParasList(QList<ParaItem> &parasList)
{
    //常用功能设置参数---------------------------
    //常用功能设置参数-常用按钮1；单位：无 ，范围全部，默认
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_COMMONFUN,
                                   0 ,
                                   1, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Frequently used button1"),//常用按钮1
                                   FUN_PATTERNSELECT, FUN_ALLTOZERO, FUN_NULL, FUN_PATTERNSELECT, 0, "", "",
                                   (QCoreApplication::translate("GLOBAL", "AllToZero:")+QString::number(FUN_ALLTOZERO)+";"+//全部归零
                                    QCoreApplication::translate("GLOBAL","SpindleTest:")+QString::number(FUN_SPINDLETEST)+";"+//冲孔主轴研车
                                    QCoreApplication::translate("GLOBAL","SetOffsetPoint:")+QString::number(FUN_SETOFFSETPOINT)+";"+//定偏移点
                                    QCoreApplication::translate("GLOBAL","BackOffsetPoint:")+QString::number(FUN_BACKOFFSETPOINT)+";"+//回偏移点
                                    QCoreApplication::translate("GLOBAL","SetStartPoint:")+QString::number(FUN_SETSTARTPOINT)+";"+//定起始点
                                    QCoreApplication::translate("GLOBAL","BackStartPoint:")+QString::number(FUN_BACKSTARTPOINT)+";"+//回起始点
                                    QCoreApplication::translate("GLOBAL","BackWorkPoint:")+QString::number(FUN_BACKWORKPOINT)+";"+//回工作点
                                    QCoreApplication::translate("GLOBAL","BackAnchorPoint:")+QString::number(FUN_BACKANCHORPOINT)+";"+//回定位点
                                    QCoreApplication::translate("GLOBAL","CheckFrame:")+QString::number(FUN_CHECKFRAME)+";"+//边框检查
                                    QCoreApplication::translate("GLOBAL","ForwardOrBackward:")+QString::number(FUN_FORWARDORBACK)+";"+//前进回退
                                    QCoreApplication::translate("GLOBAL","PunchSpindleJog:")+QString::number(FUN_PUNCHSPINDLEJOG)+";"+//冲孔主轴点动
                                    QCoreApplication::translate("GLOBAL","ManualColorChange:")+QString::number(FUN_PUNCHMANUALCHANGECOLOR)+";"+//手动换色
                                    QCoreApplication::translate("GLOBAL","SinglePunch:")+QString::number(FUN_SINGLEPUNCH)+";"+//单次冲孔
                                    QCoreApplication::translate("GLOBAL","FrameZero:")+QString::number(FUN_FRAMEZERO)+";"+//框架归零
                                    QCoreApplication::translate("GLOBAL","MoveToRightUp:")+QString::number(FUN_MOVETORIGHTUP)+";"+//去右上角
                                    QCoreApplication::translate("GLOBAL","MoveToRightDown:")+QString::number(FUN_MOVETORIGHTDOWN)+";"+//去右下角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftUp:")+QString::number(FUN_MOVETOLEFTUP)+";"+//去左上角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftDown:")+QString::number(FUN_MOVETOLEFTDOWN)+";"+//去左下角
                                    QCoreApplication::translate("GLOBAL","SetWorkRange:")+QString::number(FUN_SETWORKRANGE)+";"+//定工作范围
                                    QCoreApplication::translate("GLOBAL","PatternSelect:")+QString::number(FUN_PATTERNSELECT)+";"+//花样选择
                                    QCoreApplication::translate("GLOBAL","PunchStopLower:")+QString::number(FUN_PUNCHSTOPLOWER)+";"+//冲头停下位
                                    QCoreApplication::translate("GLOBAL","SewSpindleTest:")+QString::number(FUN_SEWSPINDLETEST)+";"+//缝纫主轴研车
                                    QCoreApplication::translate("GLOBAL","Sewing head lifting:")+QString::number(FUN_SEWMOTORUPDOWN)+";"+//缝纫机头升降
                                    QCoreApplication::translate("GLOBAL","SewSpindleJog:")+QString::number(FUN_SEWSPINDLEJOG)+";"+//缝纫主轴点动
                                    QCoreApplication::translate("GLOBAL","PunchSetStartPoint:")+QString::number(FUN_SECSETSTARTPOINT)+";"+//冲孔定起始点（第二机头定起始点）
                                    QCoreApplication::translate("GLOBAL","EmbSetStartPoint:")+QString::number(FUN_THRIDSETSTARTPOINT)+";"+//平绣定起始点
                                    QCoreApplication::translate("GLOBAL","EmbSpindleTest:")+QString::number(FUN_SEWEMBSPINDLETEST)+";"+//平绣主轴研车
                                    QCoreApplication::translate("GLOBAL","EmbSpindleJog:")+QString::number(FUN_SEWEMBSPINDLEJOG)+";"+//平绣主轴点动
                                    QCoreApplication::translate("GLOBAL","EmbChangeColor:")+QString::number(FUN_SEWEMBCHANGECOLOR)+";"+//平绣换色
                                    QCoreApplication::translate("GLOBAL","EmbCutLine:")+QString::number(FUN_SEWEMBCUTLINE)+";"+//平绣剪线
                                    QCoreApplication::translate("GLOBAL","ChangeMachineSewHead:")+QString::number(FUN_SELECTSEWHEAD)+";"+//切换缝纫机头
                                    QCoreApplication::translate("GLOBAL","ChangeMachineEmbHead:")+QString::number(FUN_SELECTEMBHEAD)+";"+//切换平绣机头
                                    QCoreApplication::translate("GLOBAL","ChangeMachinePunchHead:")+QString::number(FUN_SELECTPUCNHHEAD)+";"+//切换冲孔机头
                                    QCoreApplication::translate("GLOBAL","Sew thread trimming:")+QString::number(FUN_SEWHEADCUTLINEO)+";"+//缝纫剪线
                                    QCoreApplication::translate("GLOBAL","Sew rotate proofreading:")+QString::number(FUN_ROTATEPROOFREAD)+";"+//缝纫旋转校对
                                    QCoreApplication::translate("GLOBAL","Needle shuttle proofreading:")+QString::number(FUN_NEEDLECONTRAST)+";"+//针梭校对
                                    QCoreApplication::translate("GLOBAL","Needle shuttle reposition:")+QString::number(FUN_NEEDLESHUTTLERESET)+";"+//针梭复位
                                    QCoreApplication::translate("GLOBAL","Needle reset:")+QString::number(FUN_NEEDLERESET)+";"+//针复位
                                    QCoreApplication::translate("GLOBAL","Shuttle reset:")+QString::number(FUN_SHUTTLERESET)+";"+//梭复位
                                    QCoreApplication::translate("GLOBAL","Sew rotate up:")+QString::number(FUN_SEWROTATEUP)+";"+//缝纫旋转+
                                    QCoreApplication::translate("GLOBAL","Sew rotate down:")+QString::number(FUN_SEWROTATEDOWN)+";"+//缝纫旋转-
                                    QCoreApplication::translate("GLOBAL","BackCenter:")+QString::number(FUN_RETURNTOCENTERPOINT)+";"+//回中心点
                                    QCoreApplication::translate("GLOBAL","Null:")+QString::number(FUN_NULL)+";"),//无功能
                                   FUN_PATTERNSELECT, FUN_PATTERNSELECT, 0x0001, operate));
    //常用功能设置参数---------------------------
    //常用功能设置参数-常用按钮2；单位：无 ，范围全部，默认
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_COMMONFUN,
                                   0 ,
                                   2, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Frequently used button2"),//常用按钮2
                                   FUN_SETSTARTPOINT, FUN_ALLTOZERO, FUN_NULL, FUN_SETSTARTPOINT, 0, "", "",
                                   (QCoreApplication::translate("GLOBAL", "AllToZero:")+QString::number(FUN_ALLTOZERO)+";"+//全部归零
                                    QCoreApplication::translate("GLOBAL","SpindleTest:")+QString::number(FUN_SPINDLETEST)+";"+//冲孔主轴研车
                                    QCoreApplication::translate("GLOBAL","SetOffsetPoint:")+QString::number(FUN_SETOFFSETPOINT)+";"+//定偏移点
                                    QCoreApplication::translate("GLOBAL","BackOffsetPoint:")+QString::number(FUN_BACKOFFSETPOINT)+";"+//回偏移点
                                    QCoreApplication::translate("GLOBAL","SetStartPoint:")+QString::number(FUN_SETSTARTPOINT)+";"+//定起始点
                                    QCoreApplication::translate("GLOBAL","BackStartPoint:")+QString::number(FUN_BACKSTARTPOINT)+";"+//回起始点
                                    QCoreApplication::translate("GLOBAL","BackWorkPoint:")+QString::number(FUN_BACKWORKPOINT)+";"+//回工作点
                                    QCoreApplication::translate("GLOBAL","BackAnchorPoint:")+QString::number(FUN_BACKANCHORPOINT)+";"+//回定位点
                                    QCoreApplication::translate("GLOBAL","CheckFrame:")+QString::number(FUN_CHECKFRAME)+";"+//边框检查
                                    QCoreApplication::translate("GLOBAL","ForwardOrBackward:")+QString::number(FUN_FORWARDORBACK)+";"+//前进回退
                                    QCoreApplication::translate("GLOBAL","PunchSpindleJog:")+QString::number(FUN_PUNCHSPINDLEJOG)+";"+//冲孔主轴点动
                                    QCoreApplication::translate("GLOBAL","ManualColorChange:")+QString::number(FUN_PUNCHMANUALCHANGECOLOR)+";"+//手动换色
                                    QCoreApplication::translate("GLOBAL","SinglePunch:")+QString::number(FUN_SINGLEPUNCH)+";"+//单次冲孔
                                    QCoreApplication::translate("GLOBAL","FrameZero:")+QString::number(FUN_FRAMEZERO)+";"+//框架归零
                                    QCoreApplication::translate("GLOBAL","MoveToRightUp:")+QString::number(FUN_MOVETORIGHTUP)+";"+//去右上角
                                    QCoreApplication::translate("GLOBAL","MoveToRightDown:")+QString::number(FUN_MOVETORIGHTDOWN)+";"+//去右下角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftUp:")+QString::number(FUN_MOVETOLEFTUP)+";"+//去左上角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftDown:")+QString::number(FUN_MOVETOLEFTDOWN)+";"+//去左下角
                                    QCoreApplication::translate("GLOBAL","SetWorkRange:")+QString::number(FUN_SETWORKRANGE)+";"+//定工作范围
                                    QCoreApplication::translate("GLOBAL","PatternSelect:")+QString::number(FUN_PATTERNSELECT)+";"+//花样选择
                                    QCoreApplication::translate("GLOBAL","PunchStopLower:")+QString::number(FUN_PUNCHSTOPLOWER)+";"+//冲头停下位
                                    QCoreApplication::translate("GLOBAL","SewSpindleTest:")+QString::number(FUN_SEWSPINDLETEST)+";"+//缝纫主轴研车
                                    QCoreApplication::translate("GLOBAL","Sewing head lifting:")+QString::number(FUN_SEWMOTORUPDOWN)+";"+//缝纫机头升降
                                    QCoreApplication::translate("GLOBAL","SewSpindleJog:")+QString::number(FUN_SEWSPINDLEJOG)+";"+//缝纫主轴点动
                                    QCoreApplication::translate("GLOBAL","PunchSetStartPoint:")+QString::number(FUN_SECSETSTARTPOINT)+";"+//冲孔定起始点（第二机头定起始点）
                                    QCoreApplication::translate("GLOBAL","EmbSetStartPoint:")+QString::number(FUN_THRIDSETSTARTPOINT)+";"+//平绣定起始点
                                    QCoreApplication::translate("GLOBAL","EmbSpindleTest:")+QString::number(FUN_SEWEMBSPINDLETEST)+";"+//平绣主轴研车
                                    QCoreApplication::translate("GLOBAL","EmbSpindleJog:")+QString::number(FUN_SEWEMBSPINDLEJOG)+";"+//平绣主轴点动
                                    QCoreApplication::translate("GLOBAL","EmbChangeColor:")+QString::number(FUN_SEWEMBCHANGECOLOR)+";"+//平绣换色
                                    QCoreApplication::translate("GLOBAL","EmbCutLine:")+QString::number(FUN_SEWEMBCUTLINE)+";"+//平绣剪线
                                    QCoreApplication::translate("GLOBAL","ChangeMachineSewHead:")+QString::number(FUN_SELECTSEWHEAD)+";"+//切换缝纫机头
                                    QCoreApplication::translate("GLOBAL","ChangeMachineEmbHead:")+QString::number(FUN_SELECTEMBHEAD)+";"+//切换平绣机头
                                    QCoreApplication::translate("GLOBAL","ChangeMachinePunchHead:")+QString::number(FUN_SELECTPUCNHHEAD)+";"+//切换冲孔机头
                                    QCoreApplication::translate("GLOBAL","Sew thread trimming:")+QString::number(FUN_SEWHEADCUTLINEO)+";"+//缝纫剪线
                                    QCoreApplication::translate("GLOBAL","Sew rotate proofreading:")+QString::number(FUN_ROTATEPROOFREAD)+";"+//缝纫旋转校对
                                    QCoreApplication::translate("GLOBAL","Needle shuttle proofreading:")+QString::number(FUN_NEEDLECONTRAST)+";"+//针梭校对
                                    QCoreApplication::translate("GLOBAL","Needle shuttle reposition:")+QString::number(FUN_NEEDLESHUTTLERESET)+";"+//针梭复位
                                    QCoreApplication::translate("GLOBAL","Needle reset:")+QString::number(FUN_NEEDLERESET)+";"+//针复位
                                    QCoreApplication::translate("GLOBAL","Shuttle reset:")+QString::number(FUN_SHUTTLERESET)+";"+//梭复位
                                    QCoreApplication::translate("GLOBAL","Sew rotate up:")+QString::number(FUN_SEWROTATEUP)+";"+//缝纫旋转+
                                    QCoreApplication::translate("GLOBAL","Sew rotate down:")+QString::number(FUN_SEWROTATEDOWN)+";"+//缝纫旋转-
                                    QCoreApplication::translate("GLOBAL","BackCenter:")+QString::number(FUN_RETURNTOCENTERPOINT)+";"+//回中心点
                                    QCoreApplication::translate("GLOBAL","Null:")+QString::number(FUN_NULL)+";"),//无功能
                                   FUN_SETSTARTPOINT, FUN_SETSTARTPOINT, 0x0002, operate));

    //常用功能设置参数---------------------------
    //常用功能设置参数-常用按钮3；单位：无 ，范围全部，默认
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_COMMONFUN,
                                   0 ,
                                   3, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Frequently used button3"),//常用按钮3
                                   FUN_BACKSTARTPOINT, FUN_ALLTOZERO, FUN_NULL, FUN_BACKSTARTPOINT, 0, "", "",
                                   (QCoreApplication::translate("GLOBAL", "AllToZero:")+QString::number(FUN_ALLTOZERO)+";"+//全部归零
                                    QCoreApplication::translate("GLOBAL","SpindleTest:")+QString::number(FUN_SPINDLETEST)+";"+//冲孔主轴研车
                                    QCoreApplication::translate("GLOBAL","SetOffsetPoint:")+QString::number(FUN_SETOFFSETPOINT)+";"+//定偏移点
                                    QCoreApplication::translate("GLOBAL","BackOffsetPoint:")+QString::number(FUN_BACKOFFSETPOINT)+";"+//回偏移点
                                    QCoreApplication::translate("GLOBAL","SetStartPoint:")+QString::number(FUN_SETSTARTPOINT)+";"+//定起始点
                                    QCoreApplication::translate("GLOBAL","BackStartPoint:")+QString::number(FUN_BACKSTARTPOINT)+";"+//回起始点
                                    QCoreApplication::translate("GLOBAL","BackWorkPoint:")+QString::number(FUN_BACKWORKPOINT)+";"+//回工作点
                                    QCoreApplication::translate("GLOBAL","BackAnchorPoint:")+QString::number(FUN_BACKANCHORPOINT)+";"+//回定位点
                                    QCoreApplication::translate("GLOBAL","CheckFrame:")+QString::number(FUN_CHECKFRAME)+";"+//边框检查
                                    QCoreApplication::translate("GLOBAL","ForwardOrBackward:")+QString::number(FUN_FORWARDORBACK)+";"+//前进回退
                                    QCoreApplication::translate("GLOBAL","PunchSpindleJog:")+QString::number(FUN_PUNCHSPINDLEJOG)+";"+//冲孔主轴点动
                                    QCoreApplication::translate("GLOBAL","ManualColorChange:")+QString::number(FUN_PUNCHMANUALCHANGECOLOR)+";"+//手动换色
                                    QCoreApplication::translate("GLOBAL","SinglePunch:")+QString::number(FUN_SINGLEPUNCH)+";"+//单次冲孔
                                    QCoreApplication::translate("GLOBAL","FrameZero:")+QString::number(FUN_FRAMEZERO)+";"+//框架归零
                                    QCoreApplication::translate("GLOBAL","MoveToRightUp:")+QString::number(FUN_MOVETORIGHTUP)+";"+//去右上角
                                    QCoreApplication::translate("GLOBAL","MoveToRightDown:")+QString::number(FUN_MOVETORIGHTDOWN)+";"+//去右下角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftUp:")+QString::number(FUN_MOVETOLEFTUP)+";"+//去左上角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftDown:")+QString::number(FUN_MOVETOLEFTDOWN)+";"+//去左下角
                                    QCoreApplication::translate("GLOBAL","SetWorkRange:")+QString::number(FUN_SETWORKRANGE)+";"+//定工作范围
                                    QCoreApplication::translate("GLOBAL","PatternSelect:")+QString::number(FUN_PATTERNSELECT)+";"+//花样选择
                                    QCoreApplication::translate("GLOBAL","PunchStopLower:")+QString::number(FUN_PUNCHSTOPLOWER)+";"+//冲头停下位
                                    QCoreApplication::translate("GLOBAL","SewSpindleTest:")+QString::number(FUN_SEWSPINDLETEST)+";"+//缝纫主轴研车
                                    QCoreApplication::translate("GLOBAL","Sewing head lifting:")+QString::number(FUN_SEWMOTORUPDOWN)+";"+//缝纫机头升降
                                    QCoreApplication::translate("GLOBAL","SewSpindleJog:")+QString::number(FUN_SEWSPINDLEJOG)+";"+//缝纫主轴点动
                                    QCoreApplication::translate("GLOBAL","PunchSetStartPoint:")+QString::number(FUN_SECSETSTARTPOINT)+";"+//冲孔定起始点（第二机头定起始点）
                                    QCoreApplication::translate("GLOBAL","EmbSetStartPoint:")+QString::number(FUN_THRIDSETSTARTPOINT)+";"+//平绣定起始点
                                    QCoreApplication::translate("GLOBAL","EmbSpindleTest:")+QString::number(FUN_SEWEMBSPINDLETEST)+";"+//平绣主轴研车
                                    QCoreApplication::translate("GLOBAL","EmbSpindleJog:")+QString::number(FUN_SEWEMBSPINDLEJOG)+";"+//平绣主轴点动
                                    QCoreApplication::translate("GLOBAL","EmbChangeColor:")+QString::number(FUN_SEWEMBCHANGECOLOR)+";"+//平绣换色
                                    QCoreApplication::translate("GLOBAL","EmbCutLine:")+QString::number(FUN_SEWEMBCUTLINE)+";"+//平绣剪线
                                    QCoreApplication::translate("GLOBAL","ChangeMachineSewHead:")+QString::number(FUN_SELECTSEWHEAD)+";"+//切换缝纫机头
                                    QCoreApplication::translate("GLOBAL","ChangeMachineEmbHead:")+QString::number(FUN_SELECTEMBHEAD)+";"+//切换平绣机头
                                    QCoreApplication::translate("GLOBAL","ChangeMachinePunchHead:")+QString::number(FUN_SELECTPUCNHHEAD)+";"+//切换冲孔机头
                                    QCoreApplication::translate("GLOBAL","Sew thread trimming:")+QString::number(FUN_SEWHEADCUTLINEO)+";"+//缝纫剪线
                                    QCoreApplication::translate("GLOBAL","Sew rotate proofreading:")+QString::number(FUN_ROTATEPROOFREAD)+";"+//缝纫旋转校对
                                    QCoreApplication::translate("GLOBAL","Needle shuttle proofreading:")+QString::number(FUN_NEEDLECONTRAST)+";"+//针梭校对
                                    QCoreApplication::translate("GLOBAL","Needle shuttle reposition:")+QString::number(FUN_NEEDLESHUTTLERESET)+";"+//针梭复位
                                    QCoreApplication::translate("GLOBAL","Needle reset:")+QString::number(FUN_NEEDLERESET)+";"+//针复位
                                    QCoreApplication::translate("GLOBAL","Shuttle reset:")+QString::number(FUN_SHUTTLERESET)+";"+//梭复位
                                    QCoreApplication::translate("GLOBAL","Sew rotate up:")+QString::number(FUN_SEWROTATEUP)+";"+//缝纫旋转+
                                    QCoreApplication::translate("GLOBAL","Sew rotate down:")+QString::number(FUN_SEWROTATEDOWN)+";"+//缝纫旋转-
                                    QCoreApplication::translate("GLOBAL","BackCenter:")+QString::number(FUN_RETURNTOCENTERPOINT)+";"+//回中心点
                                    QCoreApplication::translate("GLOBAL","Null:")+QString::number(FUN_NULL)+";"),//无功能
                                   FUN_BACKSTARTPOINT, FUN_BACKSTARTPOINT, 0x0003, operate));

    //常用功能设置参数---------------------------
    //常用功能设置参数-常用按钮4；单位：无 ，范围全部，默认
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_COMMONFUN,
                                   0 ,
                                   4, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Frequently used button4"),//常用按钮4
                                   FUN_CHECKFRAME, FUN_ALLTOZERO, FUN_NULL, FUN_CHECKFRAME, 0, "", "",
                                   (QCoreApplication::translate("GLOBAL", "AllToZero:")+QString::number(FUN_ALLTOZERO)+";"+//全部归零
                                    QCoreApplication::translate("GLOBAL","SpindleTest:")+QString::number(FUN_SPINDLETEST)+";"+//冲孔主轴研车
                                    QCoreApplication::translate("GLOBAL","SetOffsetPoint:")+QString::number(FUN_SETOFFSETPOINT)+";"+//定偏移点
                                    QCoreApplication::translate("GLOBAL","BackOffsetPoint:")+QString::number(FUN_BACKOFFSETPOINT)+";"+//回偏移点
                                    QCoreApplication::translate("GLOBAL","SetStartPoint:")+QString::number(FUN_SETSTARTPOINT)+";"+//定起始点
                                    QCoreApplication::translate("GLOBAL","BackStartPoint:")+QString::number(FUN_BACKSTARTPOINT)+";"+//回起始点
                                    QCoreApplication::translate("GLOBAL","BackWorkPoint:")+QString::number(FUN_BACKWORKPOINT)+";"+//回工作点
                                    QCoreApplication::translate("GLOBAL","BackAnchorPoint:")+QString::number(FUN_BACKANCHORPOINT)+";"+//回定位点
                                    QCoreApplication::translate("GLOBAL","CheckFrame:")+QString::number(FUN_CHECKFRAME)+";"+//边框检查
                                    QCoreApplication::translate("GLOBAL","ForwardOrBackward:")+QString::number(FUN_FORWARDORBACK)+";"+//前进回退
                                    QCoreApplication::translate("GLOBAL","PunchSpindleJog:")+QString::number(FUN_PUNCHSPINDLEJOG)+";"+//冲孔主轴点动
                                    QCoreApplication::translate("GLOBAL","ManualColorChange:")+QString::number(FUN_PUNCHMANUALCHANGECOLOR)+";"+//手动换色
                                    QCoreApplication::translate("GLOBAL","SinglePunch:")+QString::number(FUN_SINGLEPUNCH)+";"+//单次冲孔
                                    QCoreApplication::translate("GLOBAL","FrameZero:")+QString::number(FUN_FRAMEZERO)+";"+//框架归零
                                    QCoreApplication::translate("GLOBAL","MoveToRightUp:")+QString::number(FUN_MOVETORIGHTUP)+";"+//去右上角
                                    QCoreApplication::translate("GLOBAL","MoveToRightDown:")+QString::number(FUN_MOVETORIGHTDOWN)+";"+//去右下角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftUp:")+QString::number(FUN_MOVETOLEFTUP)+";"+//去左上角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftDown:")+QString::number(FUN_MOVETOLEFTDOWN)+";"+//去左下角
                                    QCoreApplication::translate("GLOBAL","SetWorkRange:")+QString::number(FUN_SETWORKRANGE)+";"+//定工作范围
                                    QCoreApplication::translate("GLOBAL","PatternSelect:")+QString::number(FUN_PATTERNSELECT)+";"+//花样选择
                                    QCoreApplication::translate("GLOBAL","PunchStopLower:")+QString::number(FUN_PUNCHSTOPLOWER)+";"+//冲头停下位
                                    QCoreApplication::translate("GLOBAL","SewSpindleTest:")+QString::number(FUN_SEWSPINDLETEST)+";"+//缝纫主轴研车
                                    QCoreApplication::translate("GLOBAL","Sewing head lifting:")+QString::number(FUN_SEWMOTORUPDOWN)+";"+//缝纫机头升降
                                    QCoreApplication::translate("GLOBAL","SewSpindleJog:")+QString::number(FUN_SEWSPINDLEJOG)+";"+//缝纫主轴点动
                                    QCoreApplication::translate("GLOBAL","PunchSetStartPoint:")+QString::number(FUN_SECSETSTARTPOINT)+";"+//冲孔定起始点（第二机头定起始点）
                                    QCoreApplication::translate("GLOBAL","EmbSetStartPoint:")+QString::number(FUN_THRIDSETSTARTPOINT)+";"+//平绣定起始点
                                    QCoreApplication::translate("GLOBAL","EmbSpindleTest:")+QString::number(FUN_SEWEMBSPINDLETEST)+";"+//平绣主轴研车
                                    QCoreApplication::translate("GLOBAL","EmbSpindleJog:")+QString::number(FUN_SEWEMBSPINDLEJOG)+";"+//平绣主轴点动
                                    QCoreApplication::translate("GLOBAL","EmbChangeColor:")+QString::number(FUN_SEWEMBCHANGECOLOR)+";"+//平绣换色
                                    QCoreApplication::translate("GLOBAL","EmbCutLine:")+QString::number(FUN_SEWEMBCUTLINE)+";"+//平绣剪线
                                    QCoreApplication::translate("GLOBAL","ChangeMachineSewHead:")+QString::number(FUN_SELECTSEWHEAD)+";"+//切换缝纫机头
                                    QCoreApplication::translate("GLOBAL","ChangeMachineEmbHead:")+QString::number(FUN_SELECTEMBHEAD)+";"+//切换平绣机头
                                    QCoreApplication::translate("GLOBAL","ChangeMachinePunchHead:")+QString::number(FUN_SELECTPUCNHHEAD)+";"+//切换冲孔机头
                                    QCoreApplication::translate("GLOBAL","Sew thread trimming:")+QString::number(FUN_SEWHEADCUTLINEO)+";"+//缝纫剪线
                                    QCoreApplication::translate("GLOBAL","Sew rotate proofreading:")+QString::number(FUN_ROTATEPROOFREAD)+";"+//缝纫旋转校对
                                    QCoreApplication::translate("GLOBAL","Needle shuttle proofreading:")+QString::number(FUN_NEEDLECONTRAST)+";"+//针梭校对
                                    QCoreApplication::translate("GLOBAL","Needle shuttle reposition:")+QString::number(FUN_NEEDLESHUTTLERESET)+";"+//针梭复位
                                    QCoreApplication::translate("GLOBAL","Needle reset:")+QString::number(FUN_NEEDLERESET)+";"+//针复位
                                    QCoreApplication::translate("GLOBAL","Shuttle reset:")+QString::number(FUN_SHUTTLERESET)+";"+//梭复位
                                    QCoreApplication::translate("GLOBAL","Sew rotate up:")+QString::number(FUN_SEWROTATEUP)+";"+//缝纫旋转+
                                    QCoreApplication::translate("GLOBAL","Sew rotate down:")+QString::number(FUN_SEWROTATEDOWN)+";"+//缝纫旋转-
                                    QCoreApplication::translate("GLOBAL","BackCenter:")+QString::number(FUN_RETURNTOCENTERPOINT)+";"+//回中心点
                                    QCoreApplication::translate("GLOBAL","Null:")+QString::number(FUN_NULL)+";"),//无功能
                                   FUN_CHECKFRAME, FUN_CHECKFRAME, 0x0004, operate));

    //常用功能设置参数---------------------------
    //常用功能设置参数-常用按钮5；单位：无 ，范围全部，默认
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_COMMONFUN,
                                   0 ,
                                   5, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Frequently used button5"),//常用按钮5
                                   FUN_BACKWORKPOINT, FUN_ALLTOZERO, FUN_NULL, FUN_BACKWORKPOINT, 0, "", "",
                                   (QCoreApplication::translate("GLOBAL", "AllToZero:")+QString::number(FUN_ALLTOZERO)+";"+//全部归零
                                    QCoreApplication::translate("GLOBAL","SpindleTest:")+QString::number(FUN_SPINDLETEST)+";"+//冲孔主轴研车
                                    QCoreApplication::translate("GLOBAL","SetOffsetPoint:")+QString::number(FUN_SETOFFSETPOINT)+";"+//定偏移点
                                    QCoreApplication::translate("GLOBAL","BackOffsetPoint:")+QString::number(FUN_BACKOFFSETPOINT)+";"+//回偏移点
                                    QCoreApplication::translate("GLOBAL","SetStartPoint:")+QString::number(FUN_SETSTARTPOINT)+";"+//定起始点
                                    QCoreApplication::translate("GLOBAL","BackStartPoint:")+QString::number(FUN_BACKSTARTPOINT)+";"+//回起始点
                                    QCoreApplication::translate("GLOBAL","BackWorkPoint:")+QString::number(FUN_BACKWORKPOINT)+";"+//回工作点
                                    QCoreApplication::translate("GLOBAL","BackAnchorPoint:")+QString::number(FUN_BACKANCHORPOINT)+";"+//回定位点
                                    QCoreApplication::translate("GLOBAL","CheckFrame:")+QString::number(FUN_CHECKFRAME)+";"+//边框检查
                                    QCoreApplication::translate("GLOBAL","ForwardOrBackward:")+QString::number(FUN_FORWARDORBACK)+";"+//前进回退
                                    QCoreApplication::translate("GLOBAL","PunchSpindleJog:")+QString::number(FUN_PUNCHSPINDLEJOG)+";"+//冲孔主轴点动
                                    QCoreApplication::translate("GLOBAL","ManualColorChange:")+QString::number(FUN_PUNCHMANUALCHANGECOLOR)+";"+//手动换色
                                    QCoreApplication::translate("GLOBAL","SinglePunch:")+QString::number(FUN_SINGLEPUNCH)+";"+//单次冲孔
                                    QCoreApplication::translate("GLOBAL","FrameZero:")+QString::number(FUN_FRAMEZERO)+";"+//框架归零
                                    QCoreApplication::translate("GLOBAL","MoveToRightUp:")+QString::number(FUN_MOVETORIGHTUP)+";"+//去右上角
                                    QCoreApplication::translate("GLOBAL","MoveToRightDown:")+QString::number(FUN_MOVETORIGHTDOWN)+";"+//去右下角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftUp:")+QString::number(FUN_MOVETOLEFTUP)+";"+//去左上角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftDown:")+QString::number(FUN_MOVETOLEFTDOWN)+";"+//去左下角
                                    QCoreApplication::translate("GLOBAL","SetWorkRange:")+QString::number(FUN_SETWORKRANGE)+";"+//定工作范围
                                    QCoreApplication::translate("GLOBAL","PatternSelect:")+QString::number(FUN_PATTERNSELECT)+";"+//花样选择
                                    QCoreApplication::translate("GLOBAL","PunchStopLower:")+QString::number(FUN_PUNCHSTOPLOWER)+";"+//冲头停下位
                                    QCoreApplication::translate("GLOBAL","SewSpindleTest:")+QString::number(FUN_SEWSPINDLETEST)+";"+//缝纫主轴研车
                                    QCoreApplication::translate("GLOBAL","Sewing head lifting:")+QString::number(FUN_SEWMOTORUPDOWN)+";"+//缝纫机头升降
                                    QCoreApplication::translate("GLOBAL","SewSpindleJog:")+QString::number(FUN_SEWSPINDLEJOG)+";"+//缝纫主轴点动
                                    QCoreApplication::translate("GLOBAL","PunchSetStartPoint:")+QString::number(FUN_SECSETSTARTPOINT)+";"+//冲孔定起始点（第二机头定起始点）
                                    QCoreApplication::translate("GLOBAL","EmbSetStartPoint:")+QString::number(FUN_THRIDSETSTARTPOINT)+";"+//平绣定起始点
                                    QCoreApplication::translate("GLOBAL","EmbSpindleTest:")+QString::number(FUN_SEWEMBSPINDLETEST)+";"+//平绣主轴研车
                                    QCoreApplication::translate("GLOBAL","EmbSpindleJog:")+QString::number(FUN_SEWEMBSPINDLEJOG)+";"+//平绣主轴点动
                                    QCoreApplication::translate("GLOBAL","EmbChangeColor:")+QString::number(FUN_SEWEMBCHANGECOLOR)+";"+//平绣换色
                                    QCoreApplication::translate("GLOBAL","EmbCutLine:")+QString::number(FUN_SEWEMBCUTLINE)+";"+//平绣剪线
                                    QCoreApplication::translate("GLOBAL","ChangeMachineSewHead:")+QString::number(FUN_SELECTSEWHEAD)+";"+//切换缝纫机头
                                    QCoreApplication::translate("GLOBAL","ChangeMachineEmbHead:")+QString::number(FUN_SELECTEMBHEAD)+";"+//切换平绣机头
                                    QCoreApplication::translate("GLOBAL","ChangeMachinePunchHead:")+QString::number(FUN_SELECTPUCNHHEAD)+";"+//切换冲孔机头
                                    QCoreApplication::translate("GLOBAL","Sew thread trimming:")+QString::number(FUN_SEWHEADCUTLINEO)+";"+//缝纫剪线
                                    QCoreApplication::translate("GLOBAL","Sew rotate proofreading:")+QString::number(FUN_ROTATEPROOFREAD)+";"+//缝纫旋转校对
                                    QCoreApplication::translate("GLOBAL","Needle shuttle proofreading:")+QString::number(FUN_NEEDLECONTRAST)+";"+//针梭校对
                                    QCoreApplication::translate("GLOBAL","Needle shuttle reposition:")+QString::number(FUN_NEEDLESHUTTLERESET)+";"+//针梭复位
                                    QCoreApplication::translate("GLOBAL","Needle reset:")+QString::number(FUN_NEEDLERESET)+";"+//针复位
                                    QCoreApplication::translate("GLOBAL","Shuttle reset:")+QString::number(FUN_SHUTTLERESET)+";"+//梭复位
                                    QCoreApplication::translate("GLOBAL","Sew rotate up:")+QString::number(FUN_SEWROTATEUP)+";"+//缝纫旋转+
                                    QCoreApplication::translate("GLOBAL","Sew rotate down:")+QString::number(FUN_SEWROTATEDOWN)+";"+//缝纫旋转-
                                    QCoreApplication::translate("GLOBAL","BackCenter:")+QString::number(FUN_RETURNTOCENTERPOINT)+";"+//回中心点
                                    QCoreApplication::translate("GLOBAL","Null:")+QString::number(FUN_NULL)+";"),//无功能
                                   FUN_BACKWORKPOINT, FUN_BACKWORKPOINT, 0x0005, operate));

    //常用功能设置参数---------------------------
    //常用功能设置参数-常用按钮6；单位：无 ，范围全部，默认
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_COMMONFUN,
                                   0 ,
                                   6, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Frequently used button6"),//常用按钮6
                                   FUN_SETOFFSETPOINT, FUN_ALLTOZERO, FUN_NULL, FUN_SETOFFSETPOINT, 0, "", "",
                                   (QCoreApplication::translate("GLOBAL", "AllToZero:")+QString::number(FUN_ALLTOZERO)+";"+//全部归零
                                    QCoreApplication::translate("GLOBAL","SpindleTest:")+QString::number(FUN_SPINDLETEST)+";"+//冲孔主轴研车
                                    QCoreApplication::translate("GLOBAL","SetOffsetPoint:")+QString::number(FUN_SETOFFSETPOINT)+";"+//定偏移点
                                    QCoreApplication::translate("GLOBAL","BackOffsetPoint:")+QString::number(FUN_BACKOFFSETPOINT)+";"+//回偏移点
                                    QCoreApplication::translate("GLOBAL","SetStartPoint:")+QString::number(FUN_SETSTARTPOINT)+";"+//定起始点
                                    QCoreApplication::translate("GLOBAL","BackStartPoint:")+QString::number(FUN_BACKSTARTPOINT)+";"+//回起始点
                                    QCoreApplication::translate("GLOBAL","BackWorkPoint:")+QString::number(FUN_BACKWORKPOINT)+";"+//回工作点
                                    QCoreApplication::translate("GLOBAL","BackAnchorPoint:")+QString::number(FUN_BACKANCHORPOINT)+";"+//回定位点
                                    QCoreApplication::translate("GLOBAL","CheckFrame:")+QString::number(FUN_CHECKFRAME)+";"+//边框检查
                                    QCoreApplication::translate("GLOBAL","ForwardOrBackward:")+QString::number(FUN_FORWARDORBACK)+";"+//前进回退
                                    QCoreApplication::translate("GLOBAL","PunchSpindleJog:")+QString::number(FUN_PUNCHSPINDLEJOG)+";"+//冲孔主轴点动
                                    QCoreApplication::translate("GLOBAL","ManualColorChange:")+QString::number(FUN_PUNCHMANUALCHANGECOLOR)+";"+//手动换色
                                    QCoreApplication::translate("GLOBAL","SinglePunch:")+QString::number(FUN_SINGLEPUNCH)+";"+//单次冲孔
                                    QCoreApplication::translate("GLOBAL","FrameZero:")+QString::number(FUN_FRAMEZERO)+";"+//框架归零
                                    QCoreApplication::translate("GLOBAL","MoveToRightUp:")+QString::number(FUN_MOVETORIGHTUP)+";"+//去右上角
                                    QCoreApplication::translate("GLOBAL","MoveToRightDown:")+QString::number(FUN_MOVETORIGHTDOWN)+";"+//去右下角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftUp:")+QString::number(FUN_MOVETOLEFTUP)+";"+//去左上角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftDown:")+QString::number(FUN_MOVETOLEFTDOWN)+";"+//去左下角
                                    QCoreApplication::translate("GLOBAL","SetWorkRange:")+QString::number(FUN_SETWORKRANGE)+";"+//定工作范围
                                    QCoreApplication::translate("GLOBAL","PatternSelect:")+QString::number(FUN_PATTERNSELECT)+";"+//花样选择
                                    QCoreApplication::translate("GLOBAL","PunchStopLower:")+QString::number(FUN_PUNCHSTOPLOWER)+";"+//冲头停下位
                                    QCoreApplication::translate("GLOBAL","SewSpindleTest:")+QString::number(FUN_SEWSPINDLETEST)+";"+//缝纫主轴研车
                                    QCoreApplication::translate("GLOBAL","Sewing head lifting:")+QString::number(FUN_SEWMOTORUPDOWN)+";"+//缝纫机头升降
                                    QCoreApplication::translate("GLOBAL","SewSpindleJog:")+QString::number(FUN_SEWSPINDLEJOG)+";"+//缝纫主轴点动
                                    QCoreApplication::translate("GLOBAL","PunchSetStartPoint:")+QString::number(FUN_SECSETSTARTPOINT)+";"+//冲孔定起始点（第二机头定起始点）
                                    QCoreApplication::translate("GLOBAL","EmbSetStartPoint:")+QString::number(FUN_THRIDSETSTARTPOINT)+";"+//平绣定起始点
                                    QCoreApplication::translate("GLOBAL","EmbSpindleTest:")+QString::number(FUN_SEWEMBSPINDLETEST)+";"+//平绣主轴研车
                                    QCoreApplication::translate("GLOBAL","EmbSpindleJog:")+QString::number(FUN_SEWEMBSPINDLEJOG)+";"+//平绣主轴点动
                                    QCoreApplication::translate("GLOBAL","EmbChangeColor:")+QString::number(FUN_SEWEMBCHANGECOLOR)+";"+//平绣换色
                                    QCoreApplication::translate("GLOBAL","EmbCutLine:")+QString::number(FUN_SEWEMBCUTLINE)+";"+//平绣剪线
                                    QCoreApplication::translate("GLOBAL","ChangeMachineSewHead:")+QString::number(FUN_SELECTSEWHEAD)+";"+//切换缝纫机头
                                    QCoreApplication::translate("GLOBAL","ChangeMachineEmbHead:")+QString::number(FUN_SELECTEMBHEAD)+";"+//切换平绣机头
                                    QCoreApplication::translate("GLOBAL","ChangeMachinePunchHead:")+QString::number(FUN_SELECTPUCNHHEAD)+";"+//切换冲孔机头
                                    QCoreApplication::translate("GLOBAL","Sew thread trimming:")+QString::number(FUN_SEWHEADCUTLINEO)+";"+//缝纫剪线
                                    QCoreApplication::translate("GLOBAL","Sew rotate proofreading:")+QString::number(FUN_ROTATEPROOFREAD)+";"+//缝纫旋转校对
                                    QCoreApplication::translate("GLOBAL","Needle shuttle proofreading:")+QString::number(FUN_NEEDLECONTRAST)+";"+//针梭校对
                                    QCoreApplication::translate("GLOBAL","Needle shuttle reposition:")+QString::number(FUN_NEEDLESHUTTLERESET)+";"+//针梭复位
                                    QCoreApplication::translate("GLOBAL","Needle reset:")+QString::number(FUN_NEEDLERESET)+";"+//针复位
                                    QCoreApplication::translate("GLOBAL","Shuttle reset:")+QString::number(FUN_SHUTTLERESET)+";"+//梭复位
                                    QCoreApplication::translate("GLOBAL","Sew rotate up:")+QString::number(FUN_SEWROTATEUP)+";"+//缝纫旋转+
                                    QCoreApplication::translate("GLOBAL","Sew rotate down:")+QString::number(FUN_SEWROTATEDOWN)+";"+//缝纫旋转-
                                    QCoreApplication::translate("GLOBAL","BackCenter:")+QString::number(FUN_RETURNTOCENTERPOINT)+";"+//回中心点
                                    QCoreApplication::translate("GLOBAL","Null:")+QString::number(FUN_NULL)+";"),//无功能
                                   FUN_SETOFFSETPOINT, FUN_SETOFFSETPOINT, 0x0006, operate));

    //常用功能设置参数---------------------------
    //常用功能设置参数-常用按钮7；单位：无 ，范围全部，默认
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_COMMONFUN,
                                   0 ,
                                   7, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Frequently used button7"),//常用按钮7
                                   FUN_BACKOFFSETPOINT, FUN_ALLTOZERO, FUN_NULL, FUN_BACKOFFSETPOINT, 0, "", "",
                                   (QCoreApplication::translate("GLOBAL", "AllToZero:")+QString::number(FUN_ALLTOZERO)+";"+//全部归零
                                    QCoreApplication::translate("GLOBAL","SpindleTest:")+QString::number(FUN_SPINDLETEST)+";"+//冲孔主轴研车
                                    QCoreApplication::translate("GLOBAL","SetOffsetPoint:")+QString::number(FUN_SETOFFSETPOINT)+";"+//定偏移点
                                    QCoreApplication::translate("GLOBAL","BackOffsetPoint:")+QString::number(FUN_BACKOFFSETPOINT)+";"+//回偏移点
                                    QCoreApplication::translate("GLOBAL","SetStartPoint:")+QString::number(FUN_SETSTARTPOINT)+";"+//定起始点
                                    QCoreApplication::translate("GLOBAL","BackStartPoint:")+QString::number(FUN_BACKSTARTPOINT)+";"+//回起始点
                                    QCoreApplication::translate("GLOBAL","BackWorkPoint:")+QString::number(FUN_BACKWORKPOINT)+";"+//回工作点
                                    QCoreApplication::translate("GLOBAL","BackAnchorPoint:")+QString::number(FUN_BACKANCHORPOINT)+";"+//回定位点
                                    QCoreApplication::translate("GLOBAL","CheckFrame:")+QString::number(FUN_CHECKFRAME)+";"+//边框检查
                                    QCoreApplication::translate("GLOBAL","ForwardOrBackward:")+QString::number(FUN_FORWARDORBACK)+";"+//前进回退
                                    QCoreApplication::translate("GLOBAL","PunchSpindleJog:")+QString::number(FUN_PUNCHSPINDLEJOG)+";"+//冲孔主轴点动
                                    QCoreApplication::translate("GLOBAL","ManualColorChange:")+QString::number(FUN_PUNCHMANUALCHANGECOLOR)+";"+//手动换色
                                    QCoreApplication::translate("GLOBAL","SinglePunch:")+QString::number(FUN_SINGLEPUNCH)+";"+//单次冲孔
                                    QCoreApplication::translate("GLOBAL","FrameZero:")+QString::number(FUN_FRAMEZERO)+";"+//框架归零
                                    QCoreApplication::translate("GLOBAL","MoveToRightUp:")+QString::number(FUN_MOVETORIGHTUP)+";"+//去右上角
                                    QCoreApplication::translate("GLOBAL","MoveToRightDown:")+QString::number(FUN_MOVETORIGHTDOWN)+";"+//去右下角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftUp:")+QString::number(FUN_MOVETOLEFTUP)+";"+//去左上角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftDown:")+QString::number(FUN_MOVETOLEFTDOWN)+";"+//去左下角
                                    QCoreApplication::translate("GLOBAL","SetWorkRange:")+QString::number(FUN_SETWORKRANGE)+";"+//定工作范围
                                    QCoreApplication::translate("GLOBAL","PatternSelect:")+QString::number(FUN_PATTERNSELECT)+";"+//花样选择
                                    QCoreApplication::translate("GLOBAL","PunchStopLower:")+QString::number(FUN_PUNCHSTOPLOWER)+";"+//冲头停下位
                                    QCoreApplication::translate("GLOBAL","SewSpindleTest:")+QString::number(FUN_SEWSPINDLETEST)+";"+//缝纫主轴研车
                                    QCoreApplication::translate("GLOBAL","Sewing head lifting:")+QString::number(FUN_SEWMOTORUPDOWN)+";"+//缝纫机头升降
                                    QCoreApplication::translate("GLOBAL","SewSpindleJog:")+QString::number(FUN_SEWSPINDLEJOG)+";"+//缝纫主轴点动
                                    QCoreApplication::translate("GLOBAL","PunchSetStartPoint:")+QString::number(FUN_SECSETSTARTPOINT)+";"+//冲孔定起始点（第二机头定起始点）
                                    QCoreApplication::translate("GLOBAL","EmbSetStartPoint:")+QString::number(FUN_THRIDSETSTARTPOINT)+";"+//平绣定起始点
                                    QCoreApplication::translate("GLOBAL","EmbSpindleTest:")+QString::number(FUN_SEWEMBSPINDLETEST)+";"+//平绣主轴研车
                                    QCoreApplication::translate("GLOBAL","EmbSpindleJog:")+QString::number(FUN_SEWEMBSPINDLEJOG)+";"+//平绣主轴点动
                                    QCoreApplication::translate("GLOBAL","EmbChangeColor:")+QString::number(FUN_SEWEMBCHANGECOLOR)+";"+//平绣换色
                                    QCoreApplication::translate("GLOBAL","EmbCutLine:")+QString::number(FUN_SEWEMBCUTLINE)+";"+//平绣剪线
                                    QCoreApplication::translate("GLOBAL","ChangeMachineSewHead:")+QString::number(FUN_SELECTSEWHEAD)+";"+//切换缝纫机头
                                    QCoreApplication::translate("GLOBAL","ChangeMachineEmbHead:")+QString::number(FUN_SELECTEMBHEAD)+";"+//切换平绣机头
                                    QCoreApplication::translate("GLOBAL","ChangeMachinePunchHead:")+QString::number(FUN_SELECTPUCNHHEAD)+";"+//切换冲孔机头
                                    QCoreApplication::translate("GLOBAL","Sew thread trimming:")+QString::number(FUN_SEWHEADCUTLINEO)+";"+//缝纫剪线
                                    QCoreApplication::translate("GLOBAL","Sew rotate proofreading:")+QString::number(FUN_ROTATEPROOFREAD)+";"+//缝纫旋转校对
                                    QCoreApplication::translate("GLOBAL","Needle shuttle proofreading:")+QString::number(FUN_NEEDLECONTRAST)+";"+//针梭校对
                                    QCoreApplication::translate("GLOBAL","Needle shuttle reposition:")+QString::number(FUN_NEEDLESHUTTLERESET)+";"+//针梭复位
                                    QCoreApplication::translate("GLOBAL","Needle reset:")+QString::number(FUN_NEEDLERESET)+";"+//针复位
                                    QCoreApplication::translate("GLOBAL","Shuttle reset:")+QString::number(FUN_SHUTTLERESET)+";"+//梭复位
                                    QCoreApplication::translate("GLOBAL","Sew rotate up:")+QString::number(FUN_SEWROTATEUP)+";"+//缝纫旋转+
                                    QCoreApplication::translate("GLOBAL","Sew rotate down:")+QString::number(FUN_SEWROTATEDOWN)+";"+//缝纫旋转-
                                    QCoreApplication::translate("GLOBAL","BackCenter:")+QString::number(FUN_RETURNTOCENTERPOINT)+";"+//回中心点
                                    QCoreApplication::translate("GLOBAL","Null:")+QString::number(FUN_NULL)+";"),//无功能
                                   FUN_BACKOFFSETPOINT, FUN_BACKOFFSETPOINT, 0x0007, operate));

    //常用功能设置参数---------------------------
    //常用功能设置参数-常用按钮8；单位：无 ，范围全部，默认
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_COMMONFUN,
                                   0 ,
                                   8, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Frequently used button8"),//常用按钮8
                                   FUN_PUNCHSPINDLEJOG, FUN_ALLTOZERO, FUN_NULL, FUN_PUNCHSPINDLEJOG, 0, "", "",
                                   (QCoreApplication::translate("GLOBAL", "AllToZero:")+QString::number(FUN_ALLTOZERO)+";"+//全部归零
                                    QCoreApplication::translate("GLOBAL","SpindleTest:")+QString::number(FUN_SPINDLETEST)+";"+//冲孔主轴研车
                                    QCoreApplication::translate("GLOBAL","SetOffsetPoint:")+QString::number(FUN_SETOFFSETPOINT)+";"+//定偏移点
                                    QCoreApplication::translate("GLOBAL","BackOffsetPoint:")+QString::number(FUN_BACKOFFSETPOINT)+";"+//回偏移点
                                    QCoreApplication::translate("GLOBAL","SetStartPoint:")+QString::number(FUN_SETSTARTPOINT)+";"+//定起始点
                                    QCoreApplication::translate("GLOBAL","BackStartPoint:")+QString::number(FUN_BACKSTARTPOINT)+";"+//回起始点
                                    QCoreApplication::translate("GLOBAL","BackWorkPoint:")+QString::number(FUN_BACKWORKPOINT)+";"+//回工作点
                                    QCoreApplication::translate("GLOBAL","BackAnchorPoint:")+QString::number(FUN_BACKANCHORPOINT)+";"+//回定位点
                                    QCoreApplication::translate("GLOBAL","CheckFrame:")+QString::number(FUN_CHECKFRAME)+";"+//边框检查
                                    QCoreApplication::translate("GLOBAL","ForwardOrBackward:")+QString::number(FUN_FORWARDORBACK)+";"+//前进回退
                                    QCoreApplication::translate("GLOBAL","PunchSpindleJog:")+QString::number(FUN_PUNCHSPINDLEJOG)+";"+//冲孔主轴点动
                                    QCoreApplication::translate("GLOBAL","ManualColorChange:")+QString::number(FUN_PUNCHMANUALCHANGECOLOR)+";"+//手动换色
                                    QCoreApplication::translate("GLOBAL","SinglePunch:")+QString::number(FUN_SINGLEPUNCH)+";"+//单次冲孔
                                    QCoreApplication::translate("GLOBAL","FrameZero:")+QString::number(FUN_FRAMEZERO)+";"+//框架归零
                                    QCoreApplication::translate("GLOBAL","MoveToRightUp:")+QString::number(FUN_MOVETORIGHTUP)+";"+//去右上角
                                    QCoreApplication::translate("GLOBAL","MoveToRightDown:")+QString::number(FUN_MOVETORIGHTDOWN)+";"+//去右下角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftUp:")+QString::number(FUN_MOVETOLEFTUP)+";"+//去左上角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftDown:")+QString::number(FUN_MOVETOLEFTDOWN)+";"+//去左下角
                                    QCoreApplication::translate("GLOBAL","SetWorkRange:")+QString::number(FUN_SETWORKRANGE)+";"+//定工作范围
                                    QCoreApplication::translate("GLOBAL","PatternSelect:")+QString::number(FUN_PATTERNSELECT)+";"+//花样选择
                                    QCoreApplication::translate("GLOBAL","PunchStopLower:")+QString::number(FUN_PUNCHSTOPLOWER)+";"+//冲头停下位
                                    QCoreApplication::translate("GLOBAL","SewSpindleTest:")+QString::number(FUN_SEWSPINDLETEST)+";"+//缝纫主轴研车
                                    QCoreApplication::translate("GLOBAL","Sewing head lifting:")+QString::number(FUN_SEWMOTORUPDOWN)+";"+//缝纫机头升降
                                    QCoreApplication::translate("GLOBAL","SewSpindleJog:")+QString::number(FUN_SEWSPINDLEJOG)+";"+//缝纫主轴点动
                                    QCoreApplication::translate("GLOBAL","PunchSetStartPoint:")+QString::number(FUN_SECSETSTARTPOINT)+";"+//冲孔定起始点（第二机头定起始点）
                                    QCoreApplication::translate("GLOBAL","EmbSetStartPoint:")+QString::number(FUN_THRIDSETSTARTPOINT)+";"+//平绣定起始点
                                    QCoreApplication::translate("GLOBAL","EmbSpindleTest:")+QString::number(FUN_SEWEMBSPINDLETEST)+";"+//平绣主轴研车
                                    QCoreApplication::translate("GLOBAL","EmbSpindleJog:")+QString::number(FUN_SEWEMBSPINDLEJOG)+";"+//平绣主轴点动
                                    QCoreApplication::translate("GLOBAL","EmbChangeColor:")+QString::number(FUN_SEWEMBCHANGECOLOR)+";"+//平绣换色
                                    QCoreApplication::translate("GLOBAL","EmbCutLine:")+QString::number(FUN_SEWEMBCUTLINE)+";"+//平绣剪线
                                    QCoreApplication::translate("GLOBAL","ChangeMachineSewHead:")+QString::number(FUN_SELECTSEWHEAD)+";"+//切换缝纫机头
                                    QCoreApplication::translate("GLOBAL","ChangeMachineEmbHead:")+QString::number(FUN_SELECTEMBHEAD)+";"+//切换平绣机头
                                    QCoreApplication::translate("GLOBAL","ChangeMachinePunchHead:")+QString::number(FUN_SELECTPUCNHHEAD)+";"+//切换冲孔机头
                                    QCoreApplication::translate("GLOBAL","Sew thread trimming:")+QString::number(FUN_SEWHEADCUTLINEO)+";"+//缝纫剪线
                                    QCoreApplication::translate("GLOBAL","Sew rotate proofreading:")+QString::number(FUN_ROTATEPROOFREAD)+";"+//缝纫旋转校对
                                    QCoreApplication::translate("GLOBAL","Needle shuttle proofreading:")+QString::number(FUN_NEEDLECONTRAST)+";"+//针梭校对
                                    QCoreApplication::translate("GLOBAL","Needle shuttle reposition:")+QString::number(FUN_NEEDLESHUTTLERESET)+";"+//针梭复位
                                    QCoreApplication::translate("GLOBAL","Needle reset:")+QString::number(FUN_NEEDLERESET)+";"+//针复位
                                    QCoreApplication::translate("GLOBAL","Shuttle reset:")+QString::number(FUN_SHUTTLERESET)+";"+//梭复位
                                    QCoreApplication::translate("GLOBAL","Sew rotate up:")+QString::number(FUN_SEWROTATEUP)+";"+//缝纫旋转+
                                    QCoreApplication::translate("GLOBAL","Sew rotate down:")+QString::number(FUN_SEWROTATEDOWN)+";"+//缝纫旋转-
                                    QCoreApplication::translate("GLOBAL","BackCenter:")+QString::number(FUN_RETURNTOCENTERPOINT)+";"+//回中心点
                                    QCoreApplication::translate("GLOBAL","Null:")+QString::number(FUN_NULL)+";"),//无功能
                                   FUN_PUNCHSPINDLEJOG, FUN_PUNCHSPINDLEJOG, 0x0008, operate));

    //常用功能设置参数---------------------------
    //常用功能设置参数-常用按钮9；单位：无 ，范围全部，默认
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_COMMONFUN,
                                   0 ,
                                   9, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Frequently used button9"),//常用按钮9
                                   FUN_PROCESSRESET, FUN_ALLTOZERO, FUN_NULL, FUN_PROCESSRESET, 0, "", "",
                                   (QCoreApplication::translate("GLOBAL", "AllToZero:")+QString::number(FUN_ALLTOZERO)+";"+//全部归零
                                    QCoreApplication::translate("GLOBAL","SpindleTest:")+QString::number(FUN_SPINDLETEST)+";"+//冲孔主轴研车
                                    QCoreApplication::translate("GLOBAL","SetOffsetPoint:")+QString::number(FUN_SETOFFSETPOINT)+";"+//定偏移点
                                    QCoreApplication::translate("GLOBAL","BackOffsetPoint:")+QString::number(FUN_BACKOFFSETPOINT)+";"+//回偏移点
                                    QCoreApplication::translate("GLOBAL","SetStartPoint:")+QString::number(FUN_SETSTARTPOINT)+";"+//定起始点
                                    QCoreApplication::translate("GLOBAL","BackStartPoint:")+QString::number(FUN_BACKSTARTPOINT)+";"+//回起始点
                                    QCoreApplication::translate("GLOBAL","BackWorkPoint:")+QString::number(FUN_BACKWORKPOINT)+";"+//回工作点
                                    QCoreApplication::translate("GLOBAL","BackAnchorPoint:")+QString::number(FUN_BACKANCHORPOINT)+";"+//回定位点
                                    QCoreApplication::translate("GLOBAL","CheckFrame:")+QString::number(FUN_CHECKFRAME)+";"+//边框检查
                                    QCoreApplication::translate("GLOBAL","ForwardOrBackward:")+QString::number(FUN_FORWARDORBACK)+";"+//前进回退
                                    QCoreApplication::translate("GLOBAL","PunchSpindleJog:")+QString::number(FUN_PUNCHSPINDLEJOG)+";"+//冲孔主轴点动
                                    QCoreApplication::translate("GLOBAL","ManualColorChange:")+QString::number(FUN_PUNCHMANUALCHANGECOLOR)+";"+//手动换色
                                    QCoreApplication::translate("GLOBAL","SinglePunch:")+QString::number(FUN_SINGLEPUNCH)+";"+//单次冲孔
                                    QCoreApplication::translate("GLOBAL","FrameZero:")+QString::number(FUN_FRAMEZERO)+";"+//框架归零
                                    QCoreApplication::translate("GLOBAL","MoveToRightUp:")+QString::number(FUN_MOVETORIGHTUP)+";"+//去右上角
                                    QCoreApplication::translate("GLOBAL","MoveToRightDown:")+QString::number(FUN_MOVETORIGHTDOWN)+";"+//去右下角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftUp:")+QString::number(FUN_MOVETOLEFTUP)+";"+//去左上角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftDown:")+QString::number(FUN_MOVETOLEFTDOWN)+";"+//去左下角
                                    QCoreApplication::translate("GLOBAL","SetWorkRange:")+QString::number(FUN_SETWORKRANGE)+";"+//定工作范围
                                    QCoreApplication::translate("GLOBAL","PatternSelect:")+QString::number(FUN_PATTERNSELECT)+";"+//花样选择
                                    QCoreApplication::translate("GLOBAL","PunchStopLower:")+QString::number(FUN_PUNCHSTOPLOWER)+";"+//冲头停下位
                                    QCoreApplication::translate("GLOBAL","SewSpindleTest:")+QString::number(FUN_SEWSPINDLETEST)+";"+//缝纫主轴研车
                                    QCoreApplication::translate("GLOBAL","Sewing head lifting:")+QString::number(FUN_SEWMOTORUPDOWN)+";"+//缝纫机头升降
                                    QCoreApplication::translate("GLOBAL","SewSpindleJog:")+QString::number(FUN_SEWSPINDLEJOG)+";"+//缝纫主轴点动
                                    QCoreApplication::translate("GLOBAL","PunchSetStartPoint:")+QString::number(FUN_SECSETSTARTPOINT)+";"+//冲孔定起始点（第二机头定起始点）
                                    QCoreApplication::translate("GLOBAL","EmbSetStartPoint:")+QString::number(FUN_THRIDSETSTARTPOINT)+";"+//平绣定起始点
                                    QCoreApplication::translate("GLOBAL","EmbSpindleTest:")+QString::number(FUN_SEWEMBSPINDLETEST)+";"+//平绣主轴研车
                                    QCoreApplication::translate("GLOBAL","EmbSpindleJog:")+QString::number(FUN_SEWEMBSPINDLEJOG)+";"+//平绣主轴点动
                                    QCoreApplication::translate("GLOBAL","EmbChangeColor:")+QString::number(FUN_SEWEMBCHANGECOLOR)+";"+//平绣换色
                                    QCoreApplication::translate("GLOBAL","EmbCutLine:")+QString::number(FUN_SEWEMBCUTLINE)+";"+//平绣剪线
                                    QCoreApplication::translate("GLOBAL","ChangeMachineSewHead:")+QString::number(FUN_SELECTSEWHEAD)+";"+//切换缝纫机头
                                    QCoreApplication::translate("GLOBAL","ChangeMachineEmbHead:")+QString::number(FUN_SELECTEMBHEAD)+";"+//切换平绣机头
                                    QCoreApplication::translate("GLOBAL","ChangeMachinePunchHead:")+QString::number(FUN_SELECTPUCNHHEAD)+";"+//切换冲孔机头
                                    QCoreApplication::translate("GLOBAL","Sew thread trimming:")+QString::number(FUN_SEWHEADCUTLINEO)+";"+//缝纫剪线
                                    QCoreApplication::translate("GLOBAL","Sew rotate proofreading:")+QString::number(FUN_ROTATEPROOFREAD)+";"+//缝纫旋转校对
                                    QCoreApplication::translate("GLOBAL","Needle shuttle proofreading:")+QString::number(FUN_NEEDLECONTRAST)+";"+//针梭校对
                                    QCoreApplication::translate("GLOBAL","Needle shuttle reposition:")+QString::number(FUN_NEEDLESHUTTLERESET)+";"+//针梭复位
                                    QCoreApplication::translate("GLOBAL","Needle reset:")+QString::number(FUN_NEEDLERESET)+";"+//针复位
                                    QCoreApplication::translate("GLOBAL","Shuttle reset:")+QString::number(FUN_SHUTTLERESET)+";"+//梭复位
                                    QCoreApplication::translate("GLOBAL","Sew rotate up:")+QString::number(FUN_SEWROTATEUP)+";"+//缝纫旋转+
                                    QCoreApplication::translate("GLOBAL","Sew rotate down:")+QString::number(FUN_SEWROTATEDOWN)+";"+//缝纫旋转-
                                    QCoreApplication::translate("GLOBAL","BackCenter:")+QString::number(FUN_RETURNTOCENTERPOINT)+";"+//回中心点
                                    QCoreApplication::translate("GLOBAL","Null:")+QString::number(FUN_NULL)+";"),//无功能
                                   FUN_PROCESSRESET, FUN_PROCESSRESET, 0x0009, operate));

    //常用功能设置参数---------------------------
    //常用功能设置参数-常用按钮10；单位：无 ，范围全部，默认
    parasList.append(makeAParaItem(0,
                                   PARA_TYPE_COMMONFUN,
                                   0 ,
                                   10, 0, 0, PARA_VALUE_TYPE_LIST,
                                   QCoreApplication::translate("GLOBAL", "Frequently used button10"),//常用按钮10
                                   FUN_DRAWOUTLINE, FUN_ALLTOZERO, FUN_NULL, FUN_DRAWOUTLINE, 0, "", "",
                                   (QCoreApplication::translate("GLOBAL", "AllToZero:")+QString::number(FUN_ALLTOZERO)+";"+//全部归零
                                    QCoreApplication::translate("GLOBAL","SpindleTest:")+QString::number(FUN_SPINDLETEST)+";"+//冲孔主轴研车
                                    QCoreApplication::translate("GLOBAL","SetOffsetPoint:")+QString::number(FUN_SETOFFSETPOINT)+";"+//定偏移点
                                    QCoreApplication::translate("GLOBAL","BackOffsetPoint:")+QString::number(FUN_BACKOFFSETPOINT)+";"+//回偏移点
                                    QCoreApplication::translate("GLOBAL","SetStartPoint:")+QString::number(FUN_SETSTARTPOINT)+";"+//定起始点
                                    QCoreApplication::translate("GLOBAL","BackStartPoint:")+QString::number(FUN_BACKSTARTPOINT)+";"+//回起始点
                                    QCoreApplication::translate("GLOBAL","BackWorkPoint:")+QString::number(FUN_BACKWORKPOINT)+";"+//回工作点
                                    QCoreApplication::translate("GLOBAL","BackAnchorPoint:")+QString::number(FUN_BACKANCHORPOINT)+";"+//回定位点
                                    QCoreApplication::translate("GLOBAL","CheckFrame:")+QString::number(FUN_CHECKFRAME)+";"+//边框检查
                                    QCoreApplication::translate("GLOBAL","ForwardOrBackward:")+QString::number(FUN_FORWARDORBACK)+";"+//前进回退
                                    QCoreApplication::translate("GLOBAL","PunchSpindleJog:")+QString::number(FUN_PUNCHSPINDLEJOG)+";"+//冲孔主轴点动
                                    QCoreApplication::translate("GLOBAL","ManualColorChange:")+QString::number(FUN_PUNCHMANUALCHANGECOLOR)+";"+//手动换色
                                    QCoreApplication::translate("GLOBAL","SinglePunch:")+QString::number(FUN_SINGLEPUNCH)+";"+//单次冲孔
                                    QCoreApplication::translate("GLOBAL","FrameZero:")+QString::number(FUN_FRAMEZERO)+";"+//框架归零
                                    QCoreApplication::translate("GLOBAL","MoveToRightUp:")+QString::number(FUN_MOVETORIGHTUP)+";"+//去右上角
                                    QCoreApplication::translate("GLOBAL","MoveToRightDown:")+QString::number(FUN_MOVETORIGHTDOWN)+";"+//去右下角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftUp:")+QString::number(FUN_MOVETOLEFTUP)+";"+//去左上角
                                    QCoreApplication::translate("GLOBAL","MoveToLeftDown:")+QString::number(FUN_MOVETOLEFTDOWN)+";"+//去左下角
                                    QCoreApplication::translate("GLOBAL","SetWorkRange:")+QString::number(FUN_SETWORKRANGE)+";"+//定工作范围
                                    QCoreApplication::translate("GLOBAL","PatternSelect:")+QString::number(FUN_PATTERNSELECT)+";"+//花样选择
                                    QCoreApplication::translate("GLOBAL","PunchStopLower:")+QString::number(FUN_PUNCHSTOPLOWER)+";"+//冲头停下位
                                    QCoreApplication::translate("GLOBAL","SewSpindleTest:")+QString::number(FUN_SEWSPINDLETEST)+";"+//缝纫主轴研车
                                    QCoreApplication::translate("GLOBAL","Sewing head lifting:")+QString::number(FUN_SEWMOTORUPDOWN)+";"+//缝纫机头升降
                                    QCoreApplication::translate("GLOBAL","SewSpindleJog:")+QString::number(FUN_SEWSPINDLEJOG)+";"+//缝纫主轴点动
                                    QCoreApplication::translate("GLOBAL","PunchSetStartPoint:")+QString::number(FUN_SECSETSTARTPOINT)+";"+//冲孔定起始点（第二机头定起始点）
                                    QCoreApplication::translate("GLOBAL","EmbSetStartPoint:")+QString::number(FUN_THRIDSETSTARTPOINT)+";"+//平绣定起始点
                                    QCoreApplication::translate("GLOBAL","EmbSpindleTest:")+QString::number(FUN_SEWEMBSPINDLETEST)+";"+//平绣主轴研车
                                    QCoreApplication::translate("GLOBAL","EmbSpindleJog:")+QString::number(FUN_SEWEMBSPINDLEJOG)+";"+//平绣主轴点动
                                    QCoreApplication::translate("GLOBAL","EmbChangeColor:")+QString::number(FUN_SEWEMBCHANGECOLOR)+";"+//平绣换色
                                    QCoreApplication::translate("GLOBAL","EmbCutLine:")+QString::number(FUN_SEWEMBCUTLINE)+";"+//平绣剪线
                                    QCoreApplication::translate("GLOBAL","ChangeMachineSewHead:")+QString::number(FUN_SELECTSEWHEAD)+";"+//切换缝纫机头
                                    QCoreApplication::translate("GLOBAL","ChangeMachineEmbHead:")+QString::number(FUN_SELECTEMBHEAD)+";"+//切换平绣机头
                                    QCoreApplication::translate("GLOBAL","ChangeMachinePunchHead:")+QString::number(FUN_SELECTPUCNHHEAD)+";"+//切换冲孔机头
                                    QCoreApplication::translate("GLOBAL","Sew thread trimming:")+QString::number(FUN_SEWHEADCUTLINEO)+";"+//缝纫剪线
                                    QCoreApplication::translate("GLOBAL","Sew rotate proofreading:")+QString::number(FUN_ROTATEPROOFREAD)+";"+//缝纫旋转校对
                                    QCoreApplication::translate("GLOBAL","Needle shuttle proofreading:")+QString::number(FUN_NEEDLECONTRAST)+";"+//针梭校对
                                    QCoreApplication::translate("GLOBAL","Needle shuttle reposition:")+QString::number(FUN_NEEDLESHUTTLERESET)+";"+//针梭复位
                                    QCoreApplication::translate("GLOBAL","Needle reset:")+QString::number(FUN_NEEDLERESET)+";"+//针复位
                                    QCoreApplication::translate("GLOBAL","Shuttle reset:")+QString::number(FUN_SHUTTLERESET)+";"+//梭复位
                                    QCoreApplication::translate("GLOBAL","Sew rotate up:")+QString::number(FUN_SEWROTATEUP)+";"+//缝纫旋转+
                                    QCoreApplication::translate("GLOBAL","Sew rotate down:")+QString::number(FUN_SEWROTATEDOWN)+";"+//缝纫旋转-
                                    QCoreApplication::translate("GLOBAL","BackCenter:")+QString::number(FUN_RETURNTOCENTERPOINT)+";"+//回中心点
                                    QCoreApplication::translate("GLOBAL","Null:")+QString::number(FUN_NULL)+";"),//无功能
                                   FUN_DRAWOUTLINE, FUN_DRAWOUTLINE, 0x000A, operate));

}
